@@ -1,24 +1,25 @@
 """Factory functions for creating the pyscal objects"""
 
-import logging
-from pathlib import Path
 import zipfile
-from typing import Set, Dict, Optional, Union, List, Any, Iterable
+from pathlib import Path
+from typing import Any, Dict, Iterable, List, Optional, Set, Union
 
-import pandas as pd
 import numpy as np
-import xlrd
 import openpyxl
+import pandas as pd
+import xlrd
 
+from pyscal import getLogger_pyscal
 from pyscal.utils import capillarypressure
-from .wateroil import WaterOil
+
 from .gasoil import GasOil
 from .gaswater import GasWater
-from .wateroilgas import WaterOilGas
-from .scalrecommendation import SCALrecommendation
 from .pyscallist import PyscalList
+from .scalrecommendation import SCALrecommendation
+from .wateroil import WaterOil
+from .wateroilgas import WaterOilGas
 
-logger = logging.getLogger(__name__)
+logger = getLogger_pyscal(__name__)
 
 
 def slicedict(dct: dict, keys: Iterable):
@@ -34,14 +35,14 @@ def slicedict(dct: dict, keys: Iterable):
 # for LET parameters, where the API is simplified to 'l', 'e' and 't'.
 # We are case *insensitive* in this factory class, so everything here should
 # be lower case
-WO_INIT = ["swirr", "swl", "swcr", "sorw", "sgrw", "h", "tag"]
+WO_INIT = ["swirr", "swl", "swcr", "sorw", "socr", "sgrw", "h", "tag"]
 WO_COREY_WATER = ["nw"]
 WO_WATER_ENDPOINTS = ["krwmax", "krwend"]
 WO_COREY_OIL = ["now"]
 WO_LET_WATER = ["lw", "ew", "tw"]  # Will translated to l, e and t in code below.
 WO_LET_OIL = ["low", "eow", "tow"]
 WO_LET_OIL_ALT = ["lo", "eo", "to"]  # Alternative parameter names.
-WO_OIL_ENDPOINTS = ["kroend", "krowend"]  # krowend is deprecated in favour of kroend
+WO_OIL_ENDPOINTS = ["kroend"]
 WO_SIMPLE_J = ["a", "b", "poro_ref", "perm_ref", "drho"]  # "g" is optional
 WO_SWLHEIGHT = ["swlheight"]
 WO_SWCR_ADD = ["swcr_add"]  # Relevant when swlheight is in use.
@@ -63,12 +64,12 @@ GO_COREY_OIL = ["nog"]
 GO_OIL_ENDPOINTS = [
     "kroend",
     "kromax",
-    "krogend",
 ]
+
 GO_LET_GAS = ["lg", "eg", "tg"]
 GO_LET_OIL = ["log", "eog", "tog"]
 
-GW_INIT = ["swirr", "swl", "swcr", "sgrw", "sgcr", "h", "tag"]
+GW_INIT = ["swirr", "swl", "sgl", "swcr", "sgrw", "sgcr", "h", "tag"]
 GW_COREY_WATER = ["nw"]
 GW_COREY_GAS = ["ng"]
 GW_WATER_ENDPOINTS = ["krwmax", "krwend"]
@@ -86,12 +87,7 @@ GW_SIMPLE_J_PETRO = [
     "drho",
 ]  # "g" is optional
 
-WOG_INIT = ["swirr", "swl", "swcr", "sorw", "sorg", "sgcr", "h", "tag"]
-
-DEPRECATED = {
-    "krogend": "and will be used as kroend for GasOil",
-    "krowend": "and will be used as kroend for WaterOil",
-}
+WOG_INIT = ["swirr", "swl", "swcr", "sorw", "socr", "sorg", "sgcr", "h", "tag"]
 
 
 class PyscalFactory(object):
@@ -138,7 +134,7 @@ class PyscalFactory(object):
         translated to 'l')
 
         Recognized parameters:
-          swirr, swl, swcr, sorw, sgrw, h, tag, nw, now, krwmax, krwend,
+          swirr, swl, swcr, sorw, socr, sgrw, h, tag, nw, now, krwmax, krwend,
           lw, ew, tw, low, eow, tow, lo, eo, to, kroend,
           a, a_petro, b, b_petro, poro_ref, perm_ref, drho,
           a, b, poro, perm, sigma_costau
@@ -148,7 +144,7 @@ class PyscalFactory(object):
             fast: If fast-mode should be set for constructed object.
         """
         if not params:
-            params = dict()
+            params = {}
         if not isinstance(params, dict):
             raise TypeError("Parameter to create_water_oil must be a dictionary")
 
@@ -179,16 +175,14 @@ class PyscalFactory(object):
             logger.debug("Computed swl from swlwheight to %s", str(params["swl"]))
             if "swcr" in params and params["swcr"] < params["swl"]:
                 raise ValueError(
-                    "Provided swcr={} is lower than computed swl={}".format(
-                        params["swcr"], params["swl"]
-                    )
+                    f'Provided swcr={params["swcr"]} is lower than '
+                    f'computed swl={params["swl"]}'
                 )
         elif set(WO_SWLHEIGHT).issubset(params):
             raise ValueError(
                 (
-                    "Can't initialize from SWLHEIGHT without "
-                    "sufficient simple-J parameters, needs all of: "
-                    "{}".format(WO_SWL_FROM_HEIGHT)
+                    "Can't initialize from SWLHEIGHT without sufficient "
+                    f"simple-J parameters, needs all of: {WO_SWL_FROM_HEIGHT}"
                 )
             )
 
@@ -241,9 +235,6 @@ class PyscalFactory(object):
             params, WO_LET_OIL + WO_LET_OIL_ALT + WO_OIL_ENDPOINTS
         )
         if set(WO_COREY_OIL).issubset(set(params_corey_oil)):
-            if "krowend" in params_corey_oil:
-                # (deprecation warning is triggered)
-                params_corey_oil["kroend"] = params_corey_oil.pop("krowend")
             wateroil.add_corey_oil(**params_corey_oil)
             logger.debug(
                 "Added Corey water to WaterOil object from parameters %s",
@@ -253,9 +244,6 @@ class PyscalFactory(object):
             params_let_oil["l"] = params_let_oil.pop("low")
             params_let_oil["e"] = params_let_oil.pop("eow")
             params_let_oil["t"] = params_let_oil.pop("tow")
-            if "krowend" in params_let_oil:
-                # (deprecation warning is triggered)
-                params_let_oil["kroend"] = params_let_oil.pop("krowend")
             wateroil.add_LET_oil(**params_let_oil)
             logger.debug(
                 "Added LET water to WaterOil object from parameters %s",
@@ -265,9 +253,6 @@ class PyscalFactory(object):
             params_let_oil["l"] = params_let_oil.pop("lo")
             params_let_oil["e"] = params_let_oil.pop("eo")
             params_let_oil["t"] = params_let_oil.pop("to")
-            if "krowend" in params_let_oil:
-                # (deprecation warning is triggered)
-                params_let_oil["kroend"] = params_let_oil.pop("krowend")
             wateroil.add_LET_oil(**params_let_oil)
             logger.debug(
                 "Added LET water to WaterOil object from parameters %s",
@@ -326,7 +311,7 @@ class PyscalFactory(object):
             fast: If fast-mode should be set for constructed object.
         """
         if not params:
-            params = dict()
+            params = {}
         if not isinstance(params, dict):
             raise TypeError("Parameter to create_gas_oil must be a dictionary")
 
@@ -375,9 +360,6 @@ class PyscalFactory(object):
         params_corey_oil = slicedict(params, GO_COREY_OIL + GO_OIL_ENDPOINTS)
         params_let_oil = slicedict(params, GO_LET_OIL + GO_OIL_ENDPOINTS)
         if set(GO_COREY_OIL).issubset(set(params_corey_oil)):
-            if "krogend" in params_corey_oil:
-                # (deprecation warning will be triggered)
-                params_corey_oil["kroend"] = params_corey_oil.pop("krogend")
             gasoil.add_corey_oil(**params_corey_oil)
             logger.debug(
                 "Added Corey gas to GasOil object from parameters %s",
@@ -387,9 +369,6 @@ class PyscalFactory(object):
             params_let_oil["l"] = params_let_oil.pop("log")
             params_let_oil["e"] = params_let_oil.pop("eog")
             params_let_oil["t"] = params_let_oil.pop("tog")
-            if "krogend" in params_corey_oil:
-                # (deprecation warning will be triggered)
-                params_let_oil["kroend"] = params_let_oil.pop("krogend")
             gasoil.add_LET_oil(**params_let_oil)
             logger.debug(
                 "Added LET gas to GasOil object from parameters %s",
@@ -423,7 +402,7 @@ class PyscalFactory(object):
             fast: If fast-mode should be set for constructed object.
         """
         if not params:
-            params = dict()
+            params = {}
         if not isinstance(params, dict):
             raise TypeError("Parameter to create_water_oil_gas must be a dictionary")
 
@@ -478,7 +457,7 @@ class PyscalFactory(object):
             fast: If fast-mode should be set for constructed object.
         """
         if not params:
-            params = dict()
+            params = {}
         if not isinstance(params, dict):
             raise TypeError("Parameter to create_gas_water must be a dictionary")
 
@@ -553,7 +532,11 @@ class PyscalFactory(object):
             raise ValueError('"base" case not supplied')
         if "high" not in params:
             raise ValueError('"high" case not supplied')
-        if not all([isinstance(x, dict) for x in params.values()]):
+        if not (
+            isinstance(params["low"], dict)
+            and isinstance(params["base"], dict)
+            and isinstance(params["high"], dict)
+        ):
             raise ValueError("All values in parameter dict must be dictionaries")
 
         check_deprecated(params["low"])
@@ -568,13 +551,11 @@ class PyscalFactory(object):
 
         # Check parameter availability, in order to determine phase configuration
         gaswater = all(
-            [sufficient_gas_water_params(params[case]) for case in params.keys()]
-        )
-        gasoil = all(
-            [sufficient_gas_oil_params(params[case]) for case in params.keys()]
+            sufficient_gas_water_params(params[case]) for case in params.keys()
         )
+        gasoil = all(sufficient_gas_oil_params(params[case]) for case in params.keys())
         wateroil = all(
-            [sufficient_water_oil_params(params[case]) for case in params.keys()]
+            sufficient_water_oil_params(params[case]) for case in params.keys()
         )
 
         wog_low: Union[WaterOilGas, GasWater]
@@ -609,7 +590,7 @@ class PyscalFactory(object):
             except ValueError as err:
                 raise ValueError(f"Problem with high/opt case: {err}") from err
 
-        errored = all([not wog.selfcheck() for wog in [wog_low, wog_base, wog_high]])
+        errored = all(not wog.selfcheck() for wog in [wog_low, wog_base, wog_high])
 
         if errored:
             raise ValueError("Incomplete SCAL recommendation")
@@ -646,8 +627,9 @@ class PyscalFactory(object):
         if isinstance(inputfile, (str, Path)) and Path(inputfile).is_file():
             tabular_file_format = infer_tabular_file_format(inputfile)
             if not tabular_file_format:
-                # Error message emitted by infer_file_format()
-                return pd.DataFrame()
+                raise ValueError(
+                    f"Impossible to infer file format for {inputfile}, not CSV/XLS/XLSX"
+                )
 
             if tabular_file_format == "csv" and sheet_name is not None:
                 logger.warning(
@@ -715,7 +697,6 @@ class PyscalFactory(object):
         # It is tempting to detect any NaN's at this point because that can
         # indicate merged cells, which is not supported, but that could
         # break optional comment columns which might only be defined on certain lines.
-
         if "SATNUM" not in input_df:
             raise ValueError("SATNUM must be present in CSV/XLSX file/dataframe")
 
@@ -822,16 +803,14 @@ class PyscalFactory(object):
                 params_copy["sorw"] = params["sgrw"]
                 del params_copy["sgrw"]
                 return params_copy
-            else:
-                if np.isclose(params["sgrw"], params["sorw"]):
-                    params_copy = dict(params)
-                    del params_copy["sgrw"]
-                    return params_copy
-                else:
-                    raise ValueError(
-                        f"sgrw ({params['sgrw']}) must equal sorw ({params['sorw']}) "
-                        "when both are supplied to WaterOil."
-                    )
+            if np.isclose(params["sgrw"], params["sorw"]):
+                params_copy = dict(params)
+                del params_copy["sgrw"]
+                return params_copy
+            raise ValueError(
+                f"sgrw ({params['sgrw']}) must equal sorw ({params['sorw']}) "
+                "when both are supplied to WaterOil."
+            )
         return params
 
     @staticmethod
@@ -856,9 +835,7 @@ class PyscalFactory(object):
             "opt": "high",
         }
         lowered = [value.lower() for value in casevalues]
-        remapped = [
-            aliases[value] if value in aliases.keys() else value for value in lowered
-        ]
+        remapped = [aliases.get(value, value) for value in lowered]
         not_understood = set(remapped) - set(accepted)
         if not_understood:
             raise ValueError(f"Invalid case values: {not_understood}")
@@ -926,6 +903,7 @@ class PyscalFactory(object):
         water_oil = sufficient_water_oil_params(params)
         gas_oil = sufficient_gas_oil_params(params)
         gas_water = sufficient_gas_water_params(params)
+
         if water_oil and gas_oil:
             return PyscalFactory.create_wateroilgas_list(relperm_params_df, h, fast)
         if water_oil:
@@ -934,8 +912,7 @@ class PyscalFactory(object):
             return PyscalFactory.create_gasoil_list(relperm_params_df, h, fast)
         if gas_water:
             return PyscalFactory.create_gaswater_list(relperm_params_df, h, fast)
-        logger.error("Could not determine two or three phase from parameters")
-        return None
+        raise ValueError("Could not determine two or three phase from parameters")
 
     @staticmethod
     def create_wateroilgas_list(
@@ -1205,7 +1182,7 @@ def infer_tabular_file_format(filename: Union[str, Path]) -> str:
     try:
         pd.read_excel(filename, engine="xlrd")
         return "xls"
-    except (ValueError, xlrd.biffh.XLRDError):
+    except (ValueError, TypeError, xlrd.biffh.XLRDError):
         # We get here for both CSV and XLSX files.
         pass
     try:
@@ -1221,9 +1198,6 @@ def infer_tabular_file_format(filename: Union[str, Path]) -> str:
         logger.error("Message from CSV parser: %s", str(csverror))
         # (Some text file that is not CSV)
 
-    logger.error(
-        "Impossible to infer file format for %s, not CSV/XLS/XLSX", str(filename)
-    )
     return ""
 
 
@@ -1233,10 +1207,9 @@ def check_deprecated(params: Dict[str, Any]) -> None:
     Args:
         params: Dictionary of parameters for which only the keys are used here.
     """
-    for key in params:
-        if key.lower() in DEPRECATED:
-            logger.warning(
-                "The key %s is deprecated %s",
-                key,
-                DEPRECATED[key.lower()],
-            )
+    # Block long deprecated parameters with an exception.
+    # Remove this block in pyscal 1.x
+    if "krowend" in params and "kroend" not in params:
+        raise ValueError("krowend is not supported by pyscal. Use kroend")
+    if "krogend" in params and "kroend" not in params:
+        raise ValueError("krogend is not supported by pyscal. Use kroend")
