@@ -1,20 +1,18 @@
 """Representing a GasOil object"""
 
-import logging
+from typing import Optional
 
 import numpy as np
 import pandas as pd
-from typing import Optional
-
 from scipy.interpolate import PchipInterpolator
 
 import pyscal
-from pyscal.utils.relperm import estimate_diffjumppoint, crosspoint
-from pyscal.utils.string import df2str, comment_formatter
 from pyscal.constants import EPSILON as epsilon
-from pyscal.constants import SWINTEGERS, MAX_EXPONENT
+from pyscal.constants import MAX_EXPONENT, SWINTEGERS
+from pyscal.utils.relperm import crosspoint, estimate_diffjumppoint, truncate_zeroness
+from pyscal.utils.string import comment_formatter, df2str
 
-logger = logging.getLogger(__name__)
+logger = pyscal.getLogger_pyscal(__name__)
 
 
 class GasOil(object):
@@ -70,6 +68,7 @@ class GasOil(object):
         tag: str = "",
         krgendanchor: str = "sorg",
         fast: bool = False,
+        _sgl: float = None,  # Only to be used by GasWater.
     ) -> None:
         if h is None:
             h = 0.01
@@ -96,16 +95,28 @@ class GasOil(object):
         swl = max(swl, swirr)  # Can't allow swl < swirr, should we warn user?
         self.swl = swl
         self.swirr = swirr
-        if not np.isclose(sorg, 0.0) and sorg < 1.0 / SWINTEGERS:
-            # Too small but nonzero sorg gives too many numerical issues.
-            logger.warning("sorg was close to zero, set to zero")
-            sorg = 0.0
-        self.sorg = sorg
-        self.sgro = sgro
 
-        self.sgcr = sgcr
+        # Avoid endpoints close to zero, set them to zero if
+        # they are below a certain limit:
+        self.sorg = truncate_zeroness(sorg, name="sorg")
+        self.sgcr = truncate_zeroness(sgcr, name="sgcr")
+        self.sgro = truncate_zeroness(sgro, name="sgro")
+
+        if not (np.isclose(self.sgro, 0) or np.isclose(self.sgro - self.sgcr, 0)):
+            raise ValueError(
+                "sgro must be zero or equal to sgcr, for compatibility with "
+                "Eclipse three-point scaling. "
+                f"sgro: {sgro}, sgcr: {sgcr}."
+            )
+
         self.tag = tag
 
+        if _sgl is not None:
+            assert -epsilon < _sgl < sgcr + epsilon, "0 <= sgl <= sgcr is required"
+            self.sgl = truncate_zeroness(_sgl, name="_sgl")
+        else:
+            self.sgl = 0.0
+
         if krgendanchor in ["sorg", ""]:
             self.krgendanchor = krgendanchor
         else:
@@ -114,36 +125,25 @@ class GasOil(object):
 
         self.fast = fast
 
-        if np.isclose(sorg, 0.0) and self.krgendanchor == "sorg":
+        if np.isclose(self.sorg, 0.0) and self.krgendanchor == "sorg":
             self.krgendanchor = ""  # This is critical to avoid bugs due to numerics.
 
-        if krgendanchor == "sorg" and not 1 - sorg - swl - sgcr > 0:
+        if self.krgendanchor == "sorg" and not 1 - self.sorg - self.swl - self.sgcr > 0:
             raise ValueError(
                 "No saturation range left for gas curve between endpoints, check input"
             )
-        if krgendanchor == "" and not 1 - swl - sgcr > 0:
+        if self.krgendanchor == "" and not 1 - self.swl - self.sgcr > 0:
             raise ValueError(
                 "No saturation range left for gas curve between endpoints, check input"
             )
 
-        if not 1 - swl - sorg - sgro > 0:
-            raise ValueError(
-                "No saturation range left for oil curve between endpoints, check input"
-            )
-
-        if not (np.isclose(sgro, 0) or np.isclose(sgro, sgcr)):
-            raise ValueError(
-                "sgro must be zero or equal to sgcr, for compatibility with "
-                "Eclipse three-point scaling. "
-                f"sgro: {sgro}, sgcr: {sgcr}."
-            )
-
         sg_list = (
             [0.0]
-            + [sgcr]
-            + list(np.arange(sgcr + self.h, 1 - sorg - swl, self.h))
-            + [1 - sorg - swl]
-            + [1 - swl]
+            + [self.sgl]
+            + [self.sgcr]
+            + list(np.arange(self.sgcr + self.h, 1 - self.sorg - self.swl, self.h))
+            + [1 - self.sorg - self.swl]
+            + [1 - self.swl]
         )
         sg_list.sort()
         self.table = pd.DataFrame(sg_list, columns=["SG"])
@@ -161,48 +161,36 @@ class GasOil(object):
 
         sgcrindex = (self.table["SG"] - (self.sgcr)).abs().sort_values().index[0]
         self.table.loc[sgcrindex, "SG"] = self.sgcr
-        if sgcrindex == 0 and sgcr > 0.0:
-            # Need to conserve sg=0
+
+        # Need to conserve sg=0 and sgcr:
+        if sgcrindex == 0 and self.sgcr > 0.0:
+            # This code is a safeguard againts truncate_zeroness(), which normally
+            # prevents this from happening.
             zero_row = pd.DataFrame({"SG": 0}, index=[0])
             self.table = pd.concat([zero_row, self.table], sort=False).reset_index(
                 drop=True
             )
 
-        # If sg=1-swl was dropped, then sorg was close to zero:
-        if not np.isclose(self.table["SG"].max(), 1 - self.swl):
-            # Add it as an extra row:
-            self.table.loc[len(self.table) + 1, "SG"] = 1 - self.swl
-            self.table.sort_values(by="SG", inplace=True)
-        # Ensure the value closest to 1-swl is actually 1-swl:
-        swl_right_index = (
-            (self.table["SG"] - (1 - self.swl)).abs().sort_values().index[0]
-        )
-        self.table.loc[swl_right_index, "SG"] = 1 - self.swl
-
         self.table.reset_index(inplace=True)
         self.table = self.table[["SG"]]
         self.table["SL"] = 1 - self.table["SG"]
         if krgendanchor == "sorg":
             # Normalized sg (sgn) is 0 at sgcr, and 1 at 1-swl-sorg
             assert 1 - swl - sgcr - sorg > epsilon
-            self.table["SGN"] = (self.table["SG"] - sgcr) / (1 - swl - sgcr - sorg)
+            self.table["SGN"] = (self.table["SG"] - self.sgcr) / (
+                1 - self.swl - self.sgcr - self.sorg
+            )
         else:
             assert 1 - swl - sgcr > epsilon
-            self.table["SGN"] = (self.table["SG"] - sgcr) / (1 - swl - sgcr)
+            self.table["SGN"] = (self.table["SG"] - self.sgcr) / (
+                1 - self.swl - self.sgcr
+            )
 
         # Normalized oil saturation should be 0 at sg=1-swl-sorg, and 1 at sg=sgro
-        self.table["SON"] = (self.table["SL"] - sorg - swl) / (1 - sorg - swl - sgro)
-        self.sgcomment = (
-            "-- swirr=%g, sgcr=%g, swl=%g, sorg=%g, sgro=%g, krgendanchor=%s\n"
-            % (
-                self.swirr,
-                self.sgcr,
-                self.swl,
-                self.sorg,
-                self.sgro,
-                self.krgendanchor,
-            )
+        self.table["SON"] = (self.table["SL"] - self.sorg - self.swl) / (
+            1 - self.sorg - self.swl - self.sgro
         )
+        self.update_sgcomment_and_sorg()
         self.krgcomment = ""
         self.krogcomment = ""
         self.pccomment = ""
@@ -211,25 +199,19 @@ class GasOil(object):
             "Initialized GasOil with %s saturation points", str(len(self.table))
         )
 
-    def resetsorg(self):
+    def update_sgcomment_and_sorg(self):
         """Recalculate sorg in case it has table data has been manipulated"""
+        self.sgcomment = (
+            f"-- swirr={self.swirr:g}, sgcr={self.sgcr:g}, swl={self.swl:g}, "
+            f"sorg={self.sorg:g}, sgro={self.sgro:g}, "
+            f"krgendanchor={self.krgendanchor}\n"
+        )
         if "KROG" in self.table.columns:
             self.sorg = (
                 1
                 - self.swl
                 - self.table[np.isclose(self.table["KROG"], 0.0)].min()["SG"]
             )
-            self.sgcomment = (
-                "-- swirr=%g, sgcr=%g, swl=%g, sorg=%g, sgro=%g, krgendanchor=%s\n"
-                % (
-                    self.swirr,
-                    self.sgcr,
-                    self.swl,
-                    self.sorg,
-                    self.sgro,
-                    self.krgendanchor,
-                )
-            )
 
     def add_fromtable(
         self,
@@ -313,7 +295,7 @@ class GasOil(object):
             self.sgcr = self.estimate_sgcr()
         if krogcolname in dframe:
             if not (dframe[krogcolname].diff().dropna() < epsilon).all():
-                raise ValueError("Incoming krogcolname not decreasing")
+                raise ValueError("Incoming krog not decreasing")
             if dframe[krogcolname].max() > 1.0:
                 raise ValueError("krog is above 1 in incoming table")
             if dframe[krogcolname].min() < 0.0:
@@ -346,8 +328,6 @@ class GasOil(object):
                 self.sgro = sgro_estimate
         if pccolname in dframe:
             # Incoming dataframe must cover the range:
-            if dframe[sgcolname].min() > self.table["SG"].min():
-                raise ValueError("Too large sgcr for pcog interpolation")
             if dframe[sgcolname].max() < self.table["SG"].max():
                 raise ValueError(
                     f"Too large swl for pcog interpolation, "
@@ -463,14 +443,6 @@ class GasOil(object):
 
         self.table.loc[0, "KROG"] = kromax
 
-        # Linear part [0, sgro] for gas-condensate:
-        sgroindex = (self.table["SG"] - (self.sgro)).abs().sort_values().index[0]
-        if sgroindex > 1:
-            self.table.loc[1 : sgroindex - 1, "KROG"] = np.nan
-            self.table["KROG"] = (
-                self.table.set_index("SG")["KROG"].interpolate(method="index").values
-            )
-
     def add_corey_gas(
         self, ng: float = 2.0, krgend: float = 1.0, krgmax: Optional[float] = None
     ):
@@ -495,10 +467,8 @@ class GasOil(object):
 
         if not krgmax:
             krgmax = 1
-        self.krgcomment = "-- Corey krg, ng=%g, krgend=%g, krgmax=%g\n" % (
-            ng,
-            krgend,
-            krgmax,
+        self.krgcomment = (
+            f"-- Corey krg, ng={ng:g}, krgend={krgend:g}, krgmax={krgmax:g}\n"
         )
 
     def add_corey_oil(
@@ -530,7 +500,7 @@ class GasOil(object):
 
         self.set_endpoints_linearpart_krog(kroend, kromax)
 
-        self.krogcomment = "-- Corey krog, nog=%g, kroend=%g" % (nog, kroend)
+        self.krogcomment = f"-- Corey krog, nog={nog:g}, kroend={kroend:g}"
         if kromax is not None:
             self.krogcomment += f", kromax={kromax:g}"
 
@@ -584,12 +554,9 @@ class GasOil(object):
 
         if not krgmax:
             krgmax = 1
-        self.krgcomment = "-- LET krg, l=%g, e=%g, t=%g, krgend=%g, krgmax=%g\n" % (
-            l,
-            e,
-            t,
-            krgend,
-            krgmax,
+        self.krgcomment = (
+            f"-- LET krg, l={l:g}, e={e:g}, t={t:g}, "
+            f"krgend={krgend:g}, krgmax={krgmax:g}\n"
         )
 
     def add_LET_oil(
@@ -630,12 +597,7 @@ class GasOil(object):
 
         self.set_endpoints_linearpart_krog(kroend, kromax)
 
-        self.krogcomment = "-- LET krog, l=%g, e=%g, t=%g, kroend=%g" % (
-            l,
-            e,
-            t,
-            kroend,
-        )
+        self.krogcomment = f"-- LET krog, l={l:g}, e={e:g}, t={t:g}, kroend={kroend:g}"
         if kromax is not None:
             self.krogcomment += f", kromax={kromax:g}"
 
@@ -753,7 +715,7 @@ class GasOil(object):
                 logger.error("KROG data not monotonically increasing")
                 error = True
         if "KRG" in self.table and not np.isclose(min(self.table["KRG"]), 0.0):
-            logger.error("KRG Must start at zero")
+            logger.error("KRG must start at zero")
             error = True
         if "PC" in self.table and self.table["PC"][0] > -epsilon:
             if not (self.table["PC"].diff().dropna() < epsilon).all():
@@ -812,7 +774,7 @@ class GasOil(object):
             string += self.krgcomment
             string += self.krogcomment
             if not self.fast:
-                string += "-- krg = krog @ sg=%1.5f\n" % self.crosspoint()
+                string += f"-- krg = krog @ sg={self.crosspoint():1.5f}\n"
             string += self.pccomment
         width = 10
         string += (
@@ -839,7 +801,7 @@ class GasOil(object):
     def slgof_df(self) -> pd.DataFrame:
         """Slice out an SLGOF table.
 
-        This is a used by the SLGOF() function, it is
+        This is used by the SLGOF() function, it is
         extracted as a single function to facilitate testing."""
         if "PC" not in self.table.columns:
             # Only happens when the SLGOF function is skipped (test code)
@@ -851,29 +813,6 @@ class GasOil(object):
             .sort_values("SL")[["SL", "KRG", "KROG", "PC"]]
             .reset_index(drop=True)
         )
-        # It is a strict requirement that the first sl value should be swl + sorg,
-        # so we modify it if it close. If it is not close, we do not dare to fix
-        # it, to ensure we don't cover bugs.
-        slgof_sl_mismatch = abs(slgof["SL"].values[0] - (self.sorg + self.swl))
-        if slgof_sl_mismatch > epsilon:
-            if slgof_sl_mismatch < 2 * 1.0 / float(SWINTEGERS):
-                # Repair the table in-place:
-                slgof.loc[0, "SL"] = self.sorg + self.swl
-                # After modification, we can get duplicate sl values,
-                # so drop duplicates:
-                slgof["slint"] = list(
-                    map(int, list(map(round, slgof["SL"] * SWINTEGERS)))
-                )
-                slgof.drop_duplicates("slint", inplace=True)
-                # Delete the temporary column:
-                slgof.drop(labels="slint", axis="columns", inplace=True)
-            else:
-                # Give up repairing the table:
-                logger.critical(
-                    "SLGOF does not start at the correct value. Please report as bug."
-                )
-                logger.error("slgof_sl_mismatch: %f", slgof_sl_mismatch)
-                logger.error(str(slgof.head()))
         return slgof
 
     def SLGOF(self, header: bool = True, dataincommentrow: bool = True) -> str:
@@ -908,7 +847,7 @@ class GasOil(object):
             string += self.sgcomment
             string += self.krgcomment
             string += self.krogcomment
-            string += "-- krg = krog @ sg=%1.5f\n" % self.crosspoint()
+            string += f"-- krg = krog @ sg={self.crosspoint():1.5f}\n"
             string += self.pccomment
         width = 10
         string += (
@@ -981,7 +920,7 @@ class GasOil(object):
             string += self.krgcomment
             if crosspointcomment is None:
                 if "KROG" in self.table.columns:
-                    string += "-- krg = krog @ sg=%1.5f\n" % self.crosspoint()
+                    string += f"-- krg = krog @ sg={self.crosspoint():1.5f}\n"
             else:
                 string += crosspointcomment
             string += self.pccomment
@@ -1035,7 +974,7 @@ class GasOil(object):
             string += self.sgcomment.replace("--", "!")
             string += self.krgcomment.replace("--", "!")
             string += self.krogcomment.replace("--", "!")
-            string += "! krg = krog @ sw=%1.5f\n" % self.crosspoint()
+            string += f"! krg = krog @ sw={self.crosspoint():1.5f}\n"
             string += self.pccomment.replace("--", "!")
         width = 10
         string += (
@@ -1077,8 +1016,8 @@ class GasOil(object):
         """
         # pylint: disable=import-outside-toplevel
         # Lazy import of matplotlib for speed reasons
-        import matplotlib.pyplot as plt
         import matplotlib
+        import matplotlib.pyplot as plt
 
         if mpl_ax is None:
             matplotlib.style.use("ggplot")
