@@ -1,18 +1,23 @@
 """Command line tool for pyscal"""
 
-import sys
 import argparse
-import warnings
+import sys
 import traceback
-from typing import List, Optional
+from pathlib import Path
+from typing import Optional
 
-import logging
+import pandas as pd
+
+from pyscal import (
+    GasWater,
+    SCALrecommendation,
+    WaterOilGas,
+    __version__,
+    getLogger_pyscal,
+)
 
-from pyscal import __version__, WaterOilGas, GasWater, SCALrecommendation
 from .factory import PyscalFactory
 
-logger = logging.getLogger(__name__)
-
 EPILOG = """
 The parameter file should contain a table with at least the column
 SATNUM, containing only consecutive integers starting at 1. Each row
@@ -28,11 +33,11 @@ Corey or LET parametrization are based on presence of the columns
 'Nw', 'Now', 'Nog', 'Ng', 'Lw', 'Ew', 'Tw', 'Low', 'Eow', 'Tow',
 'Log', 'Eog', 'Tog', 'Lg', 'Eg', 'Tg'.
 
-Simple J-function for capillary pressure is used if the columns
+Simple J-function for capillary pressure ("RMS" version) is used if the columns
 'a', 'b', 'poro_ref', 'perm_ref' and 'drho' are found. If you provide
-'a_petro', or 'b_petro', the petrophysical formulation of the simple
-J-function is used. Check API for exact formulas. Normalized J-function
-is used if 'a', 'b', 'poro', 'perm' and 'sigma_costau' is provided.
+'a_petro', or 'b_petro', the petrophysical formulation of the simple J-function
+is used. Check API for exact formulas. Normalized J-function is used if 'a',
+'b', 'poro', 'perm' and 'sigma_costau' is provided.
 
 For SCAL recommendations, there should be exactly three rows for each SATNUM,
 tagged with the strings 'low', 'base' and 'high' in the column 'CASE'
@@ -171,8 +176,8 @@ def pyscal_main(
     debug: bool = False,
     output: str = "relperm.inc",
     delta_s: Optional[float] = None,
-    int_param_wo: Optional[List[float]] = None,
-    int_param_go: Optional[List[Optional[float]]] = None,
+    int_param_wo: Optional[float] = None,
+    int_param_go: Optional[float] = None,
     sheet_name: str = None,
     slgof: bool = False,
     family2: bool = False,
@@ -187,47 +192,43 @@ def pyscal_main(
         debug: debug mode or not
         output: Output filename
         delta_s: Saturation step-length
-        int_param_wo: Interpolation params for wateroil
-        int_param_go: Interpolation params for gasoil
+        int_param_wo: Interpolation parameter for wateroil
+        int_param_go: Interpolation parameter for gasoil
         sheet_name: Which sheet in XLSX file
         slgof: Use SLGOF
         family2: Dump family 2 keywords
     """
 
-    if verbose:
-        logging.basicConfig(level=logging.INFO)
-    if debug:
-        logging.basicConfig(level=logging.DEBUG)
+    logger = getLogger_pyscal(
+        __name__, {"debug": debug, "verbose": verbose, "output": output}
+    )
 
-    scalinput_df = PyscalFactory.load_relperm_df(parametertable, sheet_name=sheet_name)
+    parametertable = PyscalFactory.load_relperm_df(
+        parametertable, sheet_name=sheet_name
+    )
 
-    logger.debug("Input data:\n%s", scalinput_df.to_string(index=False))
+    assert isinstance(parametertable, pd.DataFrame)
+    logger.debug("Input data:\n%s", parametertable.to_string(index=False))
 
     if int_param_go is not None and int_param_wo is None:
         raise ValueError("Don't use int_param_go alone, only int_param_wo")
-    if (
-        int_param_wo is not None
-        and isinstance(int_param_wo, list)
-        and len(int_param_wo) > 1
-    ) or (
-        int_param_go is not None
-        and isinstance(int_param_go, list)
-        and len(int_param_go) > 1
-    ):
-        warnings.warn(
-            "SATNUM specific interpolation parameters are deprecated in "
-            "the pyscal command line client. "
-            "Use interp_relperm from subscript or the API directly",
-            FutureWarning,
+    if isinstance(int_param_wo, list) or isinstance(int_param_go, list):
+        raise TypeError(
+            "SATNUM specific interpolation parameters are not supported in pyscalcli"
         )
-    if "SATNUM" not in scalinput_df:
+    if int_param_wo is not None and "CASE" not in parametertable:
+        raise ValueError(
+            "Interpolation parameter provided but no CASE column in input data"
+        )
+    if "SATNUM" not in parametertable:
         raise ValueError("There is no column called SATNUM in the input data")
-    if "CASE" in scalinput_df:
+
+    if "CASE" in parametertable:
         # Then we should do interpolation
         if int_param_wo is None:
             raise ValueError("No interpolation parameters provided")
         scalrec_list = PyscalFactory.create_scal_recommendation_list(
-            scalinput_df, h=delta_s
+            parametertable, h=delta_s
         )
         assert isinstance(scalrec_list[1], SCALrecommendation)
         if scalrec_list[1].type == WaterOilGas:
@@ -245,31 +246,24 @@ def pyscal_main(
             wog_list = scalrec_list.interpolate(int_param_wo, None, h=delta_s)
     else:
         wog_list = PyscalFactory.create_pyscal_list(
-            scalinput_df, h=delta_s
+            parametertable, h=delta_s
         )  # can be both water-oil, water-oil-gas, or gas-water
 
-    if (
-        int_param_wo is not None or int_param_go is not None
-    ) and "CASE" not in scalinput_df:
-        raise ValueError(
-            "Interpolation parameter provided but no CASE column in input data"
-        )
-
     if family2 or wog_list.pyscaltype == GasWater:
-        logger.info("Generating family 2 keywords.")
-        if output == "-":
-            print(wog_list.dump_family_2())
-        else:
-            wog_list.dump_family_2(filename=output)
-            print("Written to " + output)
+        family = 2
     else:
-        logger.info("Generating family 1 keywords.")
-        if output == "-":
-            print(wog_list.dump_family_1(slgof=slgof))
-        else:
-            wog_list.dump_family_1(filename=output, slgof=slgof)
-            print("Written to " + output)
+        family = 1
 
-
-if __name__ == "__main__":
-    main()
+    if output == "-":
+        print(wog_list.build_eclipse_data(family=family, slgof=slgof))
+    else:
+        if not Path(output).parent.exists():
+            logger.warning(
+                "Implicit directory creation is deprecated.\n"
+                "Please create the output directory prior to calling pyscal."
+            )
+            Path(output).parent.mkdir(exist_ok=True, parents=True)
+        Path(output).write_text(
+            wog_list.build_eclipse_data(family=family, slgof=slgof), encoding="utf-8"
+        )
+        print("Written to " + output)
