@@ -1,19 +1,27 @@
 """Container class for list of Pyscal objects"""
 
+import warnings
 from pathlib import Path
-import logging
-
-from typing import List, Union, Optional, Type
+from typing import List, Optional, Type, Union
 
 import pandas as pd
 
-from pyscal import WaterOil, GasOil, GasWater, WaterOilGas, SCALrecommendation
+from pyscal import (
+    GasOil,
+    GasWater,
+    SCALrecommendation,
+    WaterOil,
+    WaterOilGas,
+    getLogger_pyscal,
+)
 
 PYSCAL_OBJECTS = [WaterOil, GasOil, GasWater, WaterOilGas, SCALrecommendation]
 
 PyscalObjects = Union[WaterOil, GasOil, GasWater, WaterOilGas, SCALrecommendation]
 
-logger = logging.getLogger(__name__)
+logger = getLogger_pyscal(__name__)
+
+warnings.filterwarnings("default", category=DeprecationWarning, module="pyscal")
 
 
 class PyscalList(object):
@@ -98,11 +106,15 @@ class PyscalList(object):
                 assert isinstance(wateroilgas, WaterOilGas)
                 assert wateroilgas.wateroil is not None
                 assert wateroilgas.gasoil is not None
-                wateroil_cols = set(wateroilgas.wateroil.table.columns).intersection(
-                    wateroil_pyscal_cols
+                wateroil_cols = list(
+                    set(wateroilgas.wateroil.table.columns).intersection(
+                        wateroil_pyscal_cols
+                    )
                 )
-                gasoil_cols = set(wateroilgas.gasoil.table.columns).intersection(
-                    gasoil_pyscal_cols
+                gasoil_cols = list(
+                    set(wateroilgas.gasoil.table.columns).intersection(
+                        gasoil_pyscal_cols
+                    )
                 )
                 df_list.append(
                     wateroilgas.gasoil.table[gasoil_cols]
@@ -126,11 +138,15 @@ class PyscalList(object):
                 assert scalrec.base.gasoil is not None
                 assert scalrec.high.wateroil is not None
                 assert scalrec.high.gasoil is not None
-                gasoil_cols = set(scalrec.base.gasoil.table.columns).intersection(
-                    gasoil_pyscal_cols
+                gasoil_cols = list(
+                    set(scalrec.base.gasoil.table.columns).intersection(
+                        gasoil_pyscal_cols
+                    )
                 )
-                wateroil_cols = set(scalrec.base.wateroil.table.columns).intersection(
-                    wateroil_pyscal_cols
+                wateroil_cols = list(
+                    set(scalrec.base.wateroil.table.columns).intersection(
+                        wateroil_pyscal_cols
+                    )
                 )
                 df_list.append(
                     scalrec.low.gasoil.table[gasoil_cols]
@@ -167,8 +183,8 @@ class PyscalList(object):
             for (satnum, wateroil) in enumerate(self.pyscal_list):
                 assert isinstance(wateroil, WaterOil)
                 assert wateroil is not None
-                wateroil_cols = set(wateroil.table.columns).intersection(
-                    wateroil_pyscal_cols
+                wateroil_cols = list(
+                    set(wateroil.table.columns).intersection(wateroil_pyscal_cols)
                 )
                 df_list.append(
                     wateroil.table[wateroil_cols]
@@ -179,7 +195,9 @@ class PyscalList(object):
             for (satnum, gasoil) in enumerate(self.pyscal_list):
                 assert isinstance(gasoil, GasOil)
                 assert gasoil is not None
-                gasoil_cols = set(gasoil.table.columns).intersection(gasoil_pyscal_cols)
+                gasoil_cols = list(
+                    set(gasoil.table.columns).intersection(gasoil_pyscal_cols)
+                )
                 df_list.append(
                     gasoil.table[gasoil_cols]
                     .assign(SATNUM=satnum + 1)
@@ -191,57 +209,93 @@ class PyscalList(object):
             dframe.sort_values(sort_rows_on, inplace=True)
         return dframe
 
+    def relevant_keywords(self, family: int = 1, slgof: bool = False) -> List[str]:
+        """Construct a list of relevant Eclipse keywords for the data in this
+        Pyscallist object. This depends on the Pyscaltype, and which family is
+        requested"""
+
+        if family not in [1, 2]:
+            raise ValueError("Family must be either 1 or 2")
+
+        if self.pyscaltype == WaterOilGas:
+            # WaterOilGas can be of type WaterOil or GasOil when it emerges
+            # from a SCAL recommendation, signified by None-ness of attributes
+            if family == 2:
+                return ["SWFN", "SGFN", "SOF3"]
+            if self.pyscal_list[0].gasoil is None:  # type: ignore
+                return ["SWOF"]
+            if self.pyscal_list[0].wateroil is None:  # type: ignore
+                return ["SGOF"]
+            if not slgof:
+                return ["SWOF", "SGOF"]
+            return ["SWOF", "SLGOF"]
+
+        if self.pyscaltype == WaterOil:
+            if family == 2:
+                raise ValueError("Family 2 only supported for WaterOilGas and GasWater")
+            return ["SWOF"]
+
+        if self.pyscaltype == GasOil:
+            if family == 2:
+                raise ValueError("Family 2 only supported for WaterOilGas and GasWater")
+            if slgof:
+                raise ValueError("SLGOF not meaningful for GasOil")
+            return ["SGOF"]
+
+        assert self.pyscaltype == GasWater
+        if family == 2:
+            return ["SWFN", "SGFN"]
+        raise ValueError("Family 1 output not possible for GasWater")
+
+    def build_eclipse_data(self, family: int = 1, slgof: bool = False) -> str:
+        """Construct Eclipse keywords and data for relative permeability
+        properties of family 1 or 2 type.
+
+        Args:
+            slgof: Set to true of SLGOF is wanted instead of SGOF. Only applicable
+            if family is 1.
+        """
+        if family not in [1, 2]:
+            raise ValueError("Family must be either 1 or 2")
+        if len(self) == 0:
+            return ""
+        if self.pyscaltype == SCALrecommendation:
+            raise TypeError(
+                "You need to interpolate before you can dump a SCAL recommendation"
+            )
+        if family == 2 and slgof is True:
+            raise ValueError("SLGOF not meaningful for family 2")
+        keywords = self.relevant_keywords(family=family, slgof=slgof)
+        logger.info(
+            "Keywords %s (family %d) for %d SATNUMs generated",
+            ", ".join(keywords),
+            family,
+            len(self),
+        )
+        return "\n".join([getattr(self, keyword)() for keyword in keywords])
+
     def dump_family_1(self, filename: Optional[str] = None, slgof: bool = False) -> str:
         """Dumps family 1 Eclipse saturation tables to one
         filename. This means SWOF + SGOF (SGOF only if relevant)
 
+        This function is deprecated. Use build_eclipse_data() and write to
+        disk in calling code.
+
         Args:
             filename: Filename for the output to be given to Eclipse 100
             slgof: Set to true of SLGOF is wanted instead of SGOF
         """
-        if len(self) == 0:
-            return ""
-        if self.pyscaltype == SCALrecommendation:
-            logger.error(
-                "You need to interpolate before you can dump a SCAL recommendation"
-            )
-            raise TypeError
-        if self.pyscaltype == WaterOilGas:
-            # WaterOilGas can be of type WaterOil when it emerges
-            # from a SCAL recommendation, do a fragile test:
-            assert isinstance(self.pyscal_list[0], WaterOilGas)
-            if self.pyscal_list[0].gasoil is None:
-                family_1_str = self.SWOF()
-                keywords = "SWOF"
-            elif self.pyscal_list[0].wateroil is None:
-                family_1_str = self.SGOF()
-                keywords = "SGOF"
-            elif not slgof:
-                family_1_str = self.SWOF() + "\n" + self.SGOF()
-                keywords = "SWOF and SGOF"
-            else:
-                family_1_str = self.SWOF() + "\n" + self.SLGOF()
-                keywords = "SWOF and SLGOF"
-        if self.pyscaltype == WaterOil:
-            family_1_str = self.SWOF()
-            keywords = "SWOF"
-        if self.pyscaltype == GasOil:
-            family_1_str = self.SGOF()
-            keywords = "SGOF"
-            if slgof:
-                logger.warning("SLGOF not meaningful for GasOil. Ignored")
-        if self.pyscaltype == GasWater:
-            raise ValueError("Family 1 output not possible for GasWater")
+        warnings.warn("dump_family_1() is deprecated", DeprecationWarning)
+        string = self.build_eclipse_data(family=1, slgof=slgof)
         if filename is not None:
-            logger.info(
-                "Dumping family 1 keywords (%s) for %d SATNUMs to %s",
-                keywords,
-                len(self),
-                filename,
-            )
-            Path(filename).parent.mkdir(exist_ok=True, parents=True)
-            Path(filename).write_text(family_1_str, encoding="utf-8")
-        return family_1_str
+            if not Path(filename).parent.exists():
+                warnings.warn(
+                    "Please create the output directory prior to calling pyscal.",
+                    DeprecationWarning,
+                )
+                Path(filename).parent.mkdir(exist_ok=True, parents=True)
+            Path(filename).write_text(string, encoding="utf-8")
+        return string
 
     def dump_family_2(self, filename: Optional[str] = None) -> str:
         """Dumps family 2 Eclipse saturation tables to one
@@ -252,31 +306,17 @@ class PyscalList(object):
         Args:
             filename (str): Filename for the output to be given to Eclipse 100
         """
-        if len(self) == 0:
-            return ""
-        if self.pyscaltype == SCALrecommendation:
-            logger.error(
-                "You need to interpolate before you can dump a SCAL recommendation"
-            )
-            raise TypeError
-        if self.pyscaltype == WaterOilGas:
-            family_2_str = self.SWFN() + "\n" + self.SGFN() + "\n" + self.SOF3()
-            keywords = "SWFN, SGFN and SOF3"
-        elif self.pyscaltype == GasWater:
-            family_2_str = self.SWFN() + "\n" + self.SGFN() + "\n"
-            keywords = "SWFN and SGFN"
-        else:
-            raise ValueError("Family 2 only supported for WaterOilGas and GasWater")
+        warnings.warn("dump_family_2() is deprecated", DeprecationWarning)
+        string = self.build_eclipse_data(family=2, slgof=False)
         if filename is not None:
-            logger.info(
-                "Dumping family 2 keywords (%s) for %d SATNUMs to %s",
-                keywords,
-                len(self),
-                filename,
-            )
-            Path(filename).parent.mkdir(exist_ok=True, parents=True)
-            Path(filename).write_text(family_2_str, encoding="utf-8")
-        return family_2_str
+            if not Path(filename).parent.exists():
+                warnings.warn(
+                    "Please create the output directory prior to calling pyscal.",
+                    DeprecationWarning,
+                )
+                Path(filename).parent.mkdir(exist_ok=True, parents=True)
+            Path(filename).write_text(string, encoding="utf-8")
+        return string
 
     def interpolate(
         self,
@@ -301,8 +341,9 @@ class PyscalList(object):
         """
 
         if self.pyscaltype != SCALrecommendation:
-            logger.error("Can only interpolate PyscalList of type SCALrecommendation")
-            raise TypeError
+            raise TypeError(
+                "Can only interpolate PyscalList of type SCALrecommendation"
+            )
         if isinstance(int_params_wo, (float, int)):
             int_params_wo = [int_params_wo] * self.__len__()
         if isinstance(int_params_wo, list) and len(int_params_wo) == 1:
@@ -335,62 +376,59 @@ class PyscalList(object):
             )
         return wog_list
 
-    def make_ecl_output(
+    def _make_ecl_output(
         self,
         keyword: str,
-        write_to_filename: Optional[str] = None,
-        gaswater: bool = False,
+        write_to_filename: Optional[str] = None,  # Deprecated
     ) -> str:
-        """Internal helper function for constructing strings and writing to disk"""
+        """Internal helper function for constructing Eclipse include file strings
+        for individual keywords.
+
+        build_eclipse_data() will use this function.
+        """
         if self.pyscaltype == SCALrecommendation:
             raise TypeError(
                 "You need to interpolate before you can dump a SCAL recommendation"
             )
         first_obj = self.pyscal_list[0]
         outputter = getattr(first_obj, keyword)
-        if gaswater:
-            string = outputter(header=True, gaswater=gaswater)
-        else:
-            string = outputter(header=True)
+        string = outputter(header=True)
         if len(self.pyscal_list) > 1:
             for pyscal_obj in self.pyscal_list[1:]:
                 outputter = getattr(pyscal_obj, keyword)
-                if gaswater:
-                    string += outputter(header=False, gaswater=gaswater)
-                else:
-                    string += outputter(header=False)
+                string += outputter(header=False)
         if write_to_filename:
+            warnings.warn(
+                "Writing to files in pyscallist is deprecated", DeprecationWarning
+            )
             Path(write_to_filename).parent.mkdir(parents=True, exist_ok=True)
             Path(write_to_filename).write_text(string, encoding="utf-8")
         return string
 
     def SWOF(self, write_to_filename: Optional[str] = None) -> str:
-        """Make SWOF string and optionally print to file"""
-        return self.make_ecl_output("SWOF", write_to_filename)
+        """Build SWOF string"""
+        # _make_ecl_output() will warn about non-None filename being deprecated
+        return self._make_ecl_output("SWOF", write_to_filename)
 
     def SGOF(self, write_to_filename: Optional[str] = None) -> str:
-        """Make SGOF string and optionally print to file"""
-        return self.make_ecl_output("SGOF", write_to_filename)
+        """Build SGOF string"""
+        return self._make_ecl_output("SGOF", write_to_filename)
 
     def SLGOF(self, write_to_filename: Optional[str] = None) -> str:
-        """Make SLGOF string and optionally print to file"""
-        return self.make_ecl_output("SLGOF", write_to_filename)
+        """Build SLGOF string"""
+        return self._make_ecl_output("SLGOF", write_to_filename)
 
-    def SGFN(
-        self, write_to_filename: Optional[str] = None, gaswater: bool = False
-    ) -> str:
-        """Make SGFN string and optionally print to file"""
-        return self.make_ecl_output("SGFN", write_to_filename, gaswater=gaswater)
+    def SGFN(self, write_to_filename: Optional[str] = None) -> str:
+        """Build SGFN string"""
+        return self._make_ecl_output("SGFN", write_to_filename)
 
-    def SWFN(
-        self, write_to_filename: Optional[str] = None, gaswater: bool = False
-    ) -> str:
-        """Make SWFN string and optionally print to file"""
-        return self.make_ecl_output("SWFN", write_to_filename, gaswater=gaswater)
+    def SWFN(self, write_to_filename: Optional[str] = None) -> str:
+        """Build SWFN string"""
+        return self._make_ecl_output("SWFN", write_to_filename)
 
     def SOF3(self, write_to_filename: Optional[str] = None) -> str:
-        """Make SOF3 string and optionally print to file"""
-        return self.make_ecl_output("SOF3", write_to_filename)
+        """Build SOF3 string"""
+        return self._make_ecl_output("SOF3", write_to_filename)
 
     def __len__(self) -> int:
         """Return the count of Pyscal objects in the list"""
