@@ -1,15 +1,14 @@
 """SCALrecommendation, container for low, base and high WaterOilGas objects"""
 
 import copy
-import logging
-from typing import Optional, Union, Set, Type
+from typing import Optional, Set, Type, Union
 
 import numpy as np
 
-from pyscal import WaterOilGas, GasWater
-from pyscal.utils.interpolation import interpolate_wo, interpolate_go
+from pyscal import GasWater, WaterOilGas, getLogger_pyscal
+from pyscal.utils.interpolation import interpolate_go, interpolate_wo
 
-logger = logging.getLogger(__name__)
+logger = getLogger_pyscal(__name__)
 
 
 class SCALrecommendation(object):
@@ -169,12 +168,6 @@ class SCALrecommendation(object):
                 and self.high.gasoil is not None
             )
 
-        if not do_gaswater:
-            if not do_wateroil and not do_gasoil:
-                raise ValueError(
-                    "Neither WaterOil or GasOil is complete in SCAL recommendation"
-                )
-
         if parameter2 is not None:
             if not do_gasoil:
                 logger.warning("parameter2 is meaningless for water-oil only")
@@ -208,19 +201,11 @@ class SCALrecommendation(object):
         tagstring = "\n".join(tags)
         if do_gaswater:
             interpolant = GasWater(h=h, tag=tagstring)
-            if gasparameter != parameter:
-                logger.warning(
-                    "Different interpolation parameters for Water and for "
-                    "gas in GasWater, this is maybe not what you want"
-                )
         else:
             interpolant = WaterOilGas(h=h, tag=tagstring)
 
         if do_wateroil or do_gaswater:
-            tag = (
-                "SCAL recommendation interpolation to {}\n".format(parameter)
-                + tagstring
-            )
+            tag = f"SCAL recommendation interpolation to {parameter}\n" + tagstring
             assert self.low.wateroil is not None
             assert self.base.wateroil is not None
             assert self.high.wateroil is not None
@@ -228,7 +213,7 @@ class SCALrecommendation(object):
                 raise ValueError(
                     f"Interpolation parameter must be in [-1,1], got {parameter}"
                 )
-            elif np.isclose(parameter, 0.0):
+            if np.isclose(parameter, 0.0):
                 interpolant.wateroil = copy.deepcopy(self.base.wateroil)
                 interpolant.wateroil.tag = tag
             elif np.isclose(parameter, -1.0):
@@ -260,16 +245,13 @@ class SCALrecommendation(object):
             assert self.low.gasoil is not None
             assert self.base.gasoil is not None
             assert self.high.gasoil is not None
-            tag = (
-                "SCAL recommendation interpolation to {}\n".format(gasparameter)
-                + tagstring
-            )
+            tag = f"SCAL recommendation interpolation to {gasparameter}\n" + tagstring
             if abs(gasparameter) > 1.0:
                 raise ValueError(
                     "Interpolation parameter for gas must "
                     f"be in [-1,1], got {gasparameter}"
                 )
-            elif np.isclose(gasparameter, 0.0):
+            if np.isclose(gasparameter, 0.0):
                 interpolant.gasoil = copy.deepcopy(self.base.gasoil)
                 interpolant.gasoil.tag = tag
             elif np.isclose(gasparameter, -1.0):
