@@ -1,23 +1,20 @@
 """Wateroil module"""
 
 import math
-import logging
 from typing import Optional
 
 import numpy as np
 import pandas as pd
-
 from scipy.interpolate import PchipInterpolator, interp1d
 
 import pyscal
-from pyscal.utils.relperm import estimate_diffjumppoint, crosspoint
-from pyscal.utils.string import df2str, comment_formatter
-from pyscal.utils.capillarypressure import simple_J
 from pyscal.constants import EPSILON as epsilon
-from pyscal.constants import SWINTEGERS, MAX_EXPONENT
+from pyscal.constants import MAX_EXPONENT, SWINTEGERS
+from pyscal.utils.capillarypressure import simple_J
+from pyscal.utils.relperm import crosspoint, estimate_diffjumppoint, truncate_zeroness
+from pyscal.utils.string import comment_formatter, df2str
 
-
-logger = logging.getLogger(__name__)
+logger = pyscal.getLogger_pyscal(__name__)
 
 
 class WaterOil(object):
@@ -25,11 +22,11 @@ class WaterOil(object):
 
     Can hold relative permeability data, and capillary pressure.
 
-    Parametrizations for relative permeability:
+    Parametrizations for relative permeability
      * Corey
      * LET
 
-    For capillary pressure:
+    For capillary pressure
      * Simplified J-function
 
     For object initialization, only saturation endpoints must be inputted,
@@ -50,6 +47,10 @@ class WaterOil(object):
             water saturation is above this value.
         sorw: Residual oil saturation after water flooding. At this oil
             saturation, the oil has zero relative permeability.
+        socr: Critical oil saturation, oil will not be mobile before the
+            oil saturation is above socr. This parameter will default to sorw
+            and is to be used larger than sorw for oil paleo zone modelling
+            cases.
         h: Saturation step-length in the outputted table.
         tag: Optional string identifier, only used in comments.
         fast: Set to True if in order to skip some integrity checks
@@ -63,21 +64,25 @@ class WaterOil(object):
         swl: float = 0.0,
         swcr: float = 0.0,
         sorw: float = 0.0,
+        socr: Optional[float] = None,
         h: Optional[float] = None,
         tag: str = "",
         fast: bool = False,
         _sgcr: float = None,
+        _sgl: float = None,
     ) -> None:
         """Sets up the saturation range. Swirr is only relevant
         for the capillary pressure, not for relperm data.
 
-        _sgcr is only to be used by the GasWater object.
+        _sgcr and _sgl are only to be used by the GasWater object.
         """
 
         assert -epsilon < swirr < 1.0 + epsilon
         assert -epsilon < swl < 1.0 + epsilon
         assert -epsilon < swcr < 1.0 + epsilon
         assert -epsilon < sorw < 1.0 + epsilon
+        if socr is not None:
+            assert -epsilon < socr < 1.0 + epsilon
 
         if h is None:
             h = 0.01
@@ -97,20 +102,46 @@ class WaterOil(object):
 
         if _sgcr is not None:
             self.sgcr = _sgcr
+        if _sgl is not None:
+            assert swl < 1 - _sgl < 1 + epsilon, "1-sgl must be between swl and 1"
+            assert self.sgcr + epsilon > _sgl, "sgcr must be larger than sgl"
+            assert sorw + epsilon > _sgl, "sorw/sgrw must be larger than sgl"
+            self.sgl = truncate_zeroness(_sgl, name="_sgl")
+        else:
+            self.sgl = 0.0
 
         self.swirr = swirr
         self.swl = max(swl, swirr)  # Cannot allow swl < swirr. Warn?
-        if not np.isclose(sorw, 0) and sorw < 1 / SWINTEGERS:
-            # Give up handling sorw very close to zero
-            sorw = 0.0
+        self.sorw = truncate_zeroness(sorw, name="sorw")
         if self.swl < swcr < self.swl + 1 / SWINTEGERS + epsilon:
             # Give up handling swcr so close to swl
             swcr = self.swl
         self.swcr = max(self.swl, swcr)  # Cannot allow swcr < swl. Warn?
-        self.sorw = sorw
+
+        if socr is not None:
+            self.socr = truncate_zeroness(socr, name="socr")
+            if socr < self.sorw - epsilon:
+                raise ValueError(
+                    "socr must be equal to or larger than sorw, "
+                    f"socr={socr}, sorw={self.sorw}"
+                )
+            if self.sorw - epsilon < self.socr < self.sorw + 1 / SWINTEGERS + epsilon:
+                if self.sorw < self.socr or self.sorw > self.socr:
+                    # Only warn if it seems the user actually tried to set socr
+                    logger.warning("socr was close to sorw, reset to sorw")
+                self.socr = self.sorw
+        else:
+            self.socr = self.sorw
+
         self.tag = tag
         self.fast = fast
-        sw_list = list(np.arange(self.swl, 1, self.h)) + [self.swcr] + [1 - sorw] + [1]
+        sw_list = (
+            list(np.arange(self.swl, 1 - self.sgl, self.h))
+            + [self.swcr]
+            + [1 - self.sorw]
+            + [1 - self.socr]
+            + [1 - self.sgl]
+        )
         sw_list.sort()  # Using default timsort on nearly sorted data.
         self.table = pd.DataFrame(sw_list, columns=["SW"])
 
@@ -126,14 +157,18 @@ class WaterOil(object):
         sorwindex = (self.table["SW"] - (1 - self.sorw)).abs().sort_values().index[0]
         self.table.loc[sorwindex, "SW"] = 1 - self.sorw
 
+        # Same for sw=1-socr
+        socrindex = (self.table["SW"] - (1 - self.socr)).abs().sort_values().index[0]
+        self.table.loc[socrindex, "SW"] = 1 - self.socr
+
         # Same for sw=swcr:
         swcrindex = (self.table["SW"] - (self.swcr)).abs().sort_values().index[0]
         self.table.loc[swcrindex, "SW"] = self.swcr
 
         # If sw=1 was dropped, then sorw was close to zero:
-        if not np.isclose(self.table["SW"].max(), 1.0):
+        if not np.isclose(self.table["SW"].max(), 1.0 - self.sgl):
             # Add it as an extra row:
-            self.table.loc[len(self.table) + 1, "SW"] = 1.0
+            self.table.loc[len(self.table) + 1, "SW"] = 1.0 - self.sgl
             self.table.sort_values(by="SW", inplace=True)
 
         self.table.reset_index(inplace=True)
@@ -142,29 +177,30 @@ class WaterOil(object):
         # Normalize for krw:
         self.table["SWN"] = (self.table["SW"] - self.swcr) / (1 - self.swcr - self.sorw)
         # Normalize for krow:
-        self.table["SON"] = (1 - self.table["SW"] - self.sorw) / (
-            1 - self.sorw - self.swl
+        self.table["SON"] = (1 - self.table["SW"] - self.socr) / (
+            1 - self.swl - self.socr
         )
 
         # Different normalization for Sw used for capillary pressure
         self.table["SWNPC"] = (self.table["SW"] - swirr) / (1 - swirr)
 
         if _sgcr is None:
-            self.swcomment = "-- swirr=%g swl=%g swcr=%g sorw=%g\n" % (
-                self.swirr,
-                self.swl,
-                self.swcr,
-                self.sorw,
+            self.swcomment = (
+                f"-- swirr={self.swirr:g} swl={self.swl:g} "
+                f"swcr={self.swcr:g} sorw={self.sorw:g}"
             )
+            if self.socr > sorw:
+                self.swcomment += f" socr={self.socr:g}"
         else:
             # When _sgcr is defined, this object is in use by GasWater
-            self.swcomment = "-- swirr=%g swl=%g swcr=%g sgrw=%g sgcr=%g\n" % (
-                self.swirr,
-                self.swl,
-                self.swcr,
-                self.sorw,
-                self.sgcr,
+            # (sorw is aliased as sgrw, and sgcr is relevant)
+            self.swcomment = (
+                f"-- swirr={self.swirr:g} swl={self.swl:g} "
+                f"swcr={self.swcr:g} sgrw={self.sorw:g} sgcr={self.sgcr:g}"
             )
+            if _sgl is not None:
+                self.swcomment += f" sgl={self.sgl:g}"
+        self.swcomment += "\n"
 
         self.krwcomment = ""
         self.krowcomment = ""
@@ -185,6 +221,7 @@ class WaterOil(object):
         krowcomment: str = "",
         pccomment: str = "",
         sorw: Optional[float] = None,
+        socr: Optional[float] = None,
     ) -> None:
         """Interpolate relpermdata from a dataframe.
 
@@ -216,7 +253,9 @@ class WaterOil(object):
             krowcomment: Inserted into comment
             pccomment: Inserted into comment
             sorw: Explicit sorw. If None, it will be estimated from
-                the numbers in krw (or krow)
+                the numbers in krw
+            socr: Explicit socr. If None, it will be estimated from
+                the numbers in krow
         """
         # Avoid having to deal with multi-indices:
         if len(dframe.index.names) > 1:
@@ -245,12 +284,14 @@ class WaterOil(object):
 
         if (dframe[swcolname].diff() < 0).any():
             raise ValueError("SW data not sorted")
+        if sorw is None and krwcolname in dframe:
+            sorw = float(dframe[swcolname].max()) - estimate_diffjumppoint(
+                dframe, xcol=swcolname, ycol=krwcolname, side="right"
+            )
+            logger.info("Estimated sorw in tabular data to %f", sorw)
+        else:
+            sorw = 0
         if krwcolname in dframe:
-            if sorw is None:
-                sorw = float(dframe[swcolname].max()) - estimate_diffjumppoint(
-                    dframe, xcol=swcolname, ycol=krwcolname, side="right"
-                )
-                logger.info("Estimated sorw in tabular data to %f", sorw)
             assert -epsilon <= sorw <= 1 + epsilon
             if dframe[krwcolname].max() > 1.0:
                 raise ValueError("KRW is above 1 in incoming table")
@@ -275,10 +316,6 @@ class WaterOil(object):
             # Verify that incoming data is increasing (or level):
             if not (dframe[krwcolname].diff().dropna() > -epsilon).all():
                 raise ValueError("Incoming KRW not increasing")
-            if dframe[krwcolname].max() > 1.0:
-                raise ValueError("KRW is above 1 in incoming table")
-            if dframe[krwcolname].min() < 0.0:
-                raise ValueError("KRW is below 0 in incoming table")
             if sum(nonlinearpart) >= 2:
                 pchip = PchipInterpolator(
                     dframe[nonlinearpart][swcolname].astype(float),
@@ -303,22 +340,25 @@ class WaterOil(object):
             self.swcr = self.estimate_swcr()
 
         if krowcolname in dframe:
-            if sorw is None:
-                sorw = float(dframe[swcolname].max()) - estimate_diffjumppoint(
+            if socr is None:
+                socr = float(dframe[swcolname].max()) - estimate_diffjumppoint(
                     dframe, xcol=swcolname, ycol=krowcolname, side="right"
                 )
-                logger.info("Estimated sorw in tabular data from krow to %s", sorw)
-            assert -epsilon <= sorw <= 1 + epsilon
-            linearpart = dframe[swcolname] >= 1 - sorw
-            nonlinearpart = dframe[swcolname] <= 1 - sorw  # (overlapping at sorw)
+                if socr > sorw + epsilon:
+                    logger.info("Estimated socr in tabular data from krow to %s", socr)
+                else:
+                    socr = sorw
+            assert -epsilon <= socr <= 1 + epsilon
+            linearpart = dframe[swcolname] >= 1 - socr
+            nonlinearpart = dframe[swcolname] <= 1 - socr  # (overlapping at sorw)
             if sum(linearpart) < 2:
                 linearpart = pd.Series([False] * len(linearpart))
                 nonlinearpart = ~linearpart
-                sorw = 0
+                socr = 0
             if sum(nonlinearpart) < 2:
                 nonlinearpart = pd.Series([False] * len(nonlinearpart))
                 linearpart = ~nonlinearpart
-                sorw = 1 - float(self.table["SW"].min())
+                socr = 1 - float(self.table["SW"].min())
             if not np.isclose(dframe[swcolname].min(), self.table["SW"].min()):
                 raise ValueError("Incompatible swl")
             if not (dframe[krowcolname].diff().dropna() < epsilon).all():
@@ -332,8 +372,8 @@ class WaterOil(object):
                     dframe.loc[nonlinearpart, swcolname].astype(float),
                     dframe.loc[nonlinearpart, krowcolname].astype(float),
                 )
-                self.table.loc[self.table["SW"] <= 1 - sorw, "KROW"] = pchip(
-                    self.table.loc[self.table["SW"] <= 1 - sorw, "SW"]
+                self.table.loc[self.table["SW"] <= 1 - socr, "KROW"] = pchip(
+                    self.table.loc[self.table["SW"] <= 1 - socr, "SW"]
                 )
             if sum(linearpart) >= 2:
                 linearinterpolator = interp1d(
@@ -341,12 +381,12 @@ class WaterOil(object):
                     dframe.loc[linearpart, krowcolname].astype(float),
                 )
                 self.table.loc[
-                    self.table["SW"] >= 1 - sorw, "KROW"
+                    self.table["SW"] >= 1 - socr, "KROW"
                 ] = linearinterpolator(
-                    self.table.loc[self.table["SW"] >= 1 - sorw, "SW"]
+                    self.table.loc[self.table["SW"] >= 1 - socr, "SW"]
                 )
             self.table["KROW"].clip(lower=0.0, upper=1.0, inplace=True)
-            self.sorw = sorw
+            self.socr = socr
             self.krowcomment = "-- krow from tabular input" + krowcomment + "\n"
         if pccolname in dframe:
             # Incoming dataframe must cover the range:
@@ -405,10 +445,8 @@ class WaterOil(object):
 
         if not krwmax:
             krwmax = 1
-        self.krwcomment = "-- Corey krw, nw=%g, krwend=%g, krwmax=%g\n" % (
-            nw,
-            krwend,
-            krwmax,
+        self.krwcomment = (
+            f"-- Corey krw, nw={nw:g}, krwend={krwend:g}, krwmax={krwmax:g}\n"
         )
 
     def set_endpoints_linearpart_krw(
@@ -417,7 +455,7 @@ class WaterOil(object):
         """Set linear parts of krw outside endpoints.
 
         Curve will be linear from [1 - sorw, 1] (from krwmax to krwend)
-        and zero in [swl, swcr]
+        and zero in [swl, swcr].
 
         This function is used by add_corey_water(), and perhaps by other
         utility functions. It should not be necessary for end-users.
@@ -456,12 +494,10 @@ class WaterOil(object):
         # Left linear section is all zero:
         self.table.loc[self.table["SW"] < self.swcr, "KRW"] = 0
 
-    def set_endpoints_linearpart_krow(
-        self, kroend: float, kromax: Optional[float] = None
-    ) -> None:
+    def set_endpoints_linearpart_krow(self, kroend: float) -> None:
         """Set linear parts of krow outside endpoints
 
-        Curve will be zero in [1 - sorw, 1].
+        Curve will be zero in [1 - socr, 1].
 
         This function is used by add_corey_water(), and perhaps by other
         utility functions. It should not be necessary for end-users.
@@ -469,11 +505,8 @@ class WaterOil(object):
         Args:
             kroend: value of kro at swcr
         """
-        if kromax is not None:
-            logger.error("kromax is DEPRECATED, ignored")
-
-        # Set to zero above sorw:
-        self.table.loc[self.table["SW"] > 1 - self.sorw, "KROW"] = 0
+        # Set to zero above socr (usually equal to sorw):
+        self.table.loc[self.table["SW"] > 1 - self.socr - epsilon, "KROW"] = 0
 
         # Floating point issues can cause this to have become
         # slightly bigger than krowend.
@@ -524,12 +557,9 @@ class WaterOil(object):
 
         if not krwmax:
             krwmax = 1
-        self.krwcomment = "-- LET krw, l=%g, e=%g, t=%g, krwend=%g, krwmax=%g\n" % (
-            l,
-            e,
-            t,
-            krwend,
-            krwmax,
+        self.krwcomment = (
+            f"-- LET krw, l={l:g}, e={e:g}, t={t:g}, "
+            f"krwend={krwend:g}, krwmax={krwmax:g}\n"
         )
 
     def add_LET_oil(
@@ -538,7 +568,6 @@ class WaterOil(object):
         e: float = 2.0,
         t: float = 2.0,
         kroend: float = 1,
-        kromax: Optional[float] = None,
     ) -> None:
         """
         Add kro data through LET parametrization
@@ -557,9 +586,6 @@ class WaterOil(object):
         assert epsilon < t < MAX_EXPONENT
         assert 0 < kroend <= 1.0
 
-        if kromax is not None:
-            logger.error("kromax is DEPRECATED, ignored")
-
         self.table["KROW"] = (
             kroend
             * self.table["SON"] ** l
@@ -572,16 +598,11 @@ class WaterOil(object):
 
         self.set_endpoints_linearpart_krow(kroend)
 
-        self.krowcomment = "-- LET krow, l=%g, e=%g, t=%g, kroend=%g\n" % (
-            l,
-            e,
-            t,
-            kroend,
+        self.krowcomment = (
+            f"-- LET krow, l={l:g}, e={e:g}, t={t:g}, kroend={kroend:g}\n"
         )
 
-    def add_corey_oil(
-        self, now: float = 2.0, kroend: float = 1.0, kromax: Optional[float] = None
-    ) -> None:
+    def add_corey_oil(self, now: float = 2.0, kroend: float = 1.0) -> None:
         """Add kro data through the Corey parametrization
 
         Corey applies to the interval between swcr and 1 - sorw
@@ -597,18 +618,12 @@ class WaterOil(object):
         assert epsilon < now < MAX_EXPONENT
         assert 0 < kroend <= 1.0
 
-        if kromax is not None:
-            logger.error("kromax is DEPRECATED, ignored")
-
         self.table["KROW"] = kroend * self.table["SON"] ** now
         self.table.loc[self.table["SW"] >= (1 - self.sorw), "KROW"] = 0
 
         self.set_endpoints_linearpart_krow(kroend)
 
-        self.krowcomment = "-- Corey krow, now=%g, kroend=%g\n" % (
-            now,
-            kroend,
-        )
+        self.krowcomment = f"-- Corey krow, now={now:g}, kroend={kroend:g}\n"
 
     def add_simple_J(
         self,
@@ -679,8 +694,8 @@ class WaterOil(object):
         )
         self.pccomment = (
             "-- Simplified J-function for Pc; rms version, in bar\n--   "
-            + "a=%g, b=%g, poro_ref=%g, perm_ref=%g mD, drho=%g kg/m^3, g=%g m/s^2\n"
-            % (a, b, poro_ref, perm_ref, drho, g)
+            f"a={a:g}, b={b:g}, poro_ref={poro_ref:g}, perm_ref={perm_ref:g} mD,"
+            f" drho={drho:g} kg/m^3, g={g:g} m/s^2\n"
         )
 
     def add_simple_J_petro(
@@ -752,8 +767,8 @@ class WaterOil(object):
 
         self.pccomment = (
             "-- Simplified J-function for Pc, petrophysical version, in bar \n--   "
-            + "a=%g, b=%g, poro_ref=%g, perm_ref=%g mD, drho=%g kg/m^3, g=%g m/s^2\n"
-            % (a, b, poro_ref, perm_ref, drho, g)
+            f"a={a:g}, b={b:g}, poro_ref={poro_ref:g}, perm_ref={perm_ref:g} mD, "
+            f"drho={drho:g} kg/m^3, g={g:g} m/s^2\n"
         )
 
     def add_normalized_J(
@@ -819,8 +834,8 @@ class WaterOil(object):
         self.table["PC"] = tmp * pascal_to_bar
         self.pccomment = (
             "-- Capillary pressure from normalized J-function, in bar\n"
-            + "-- a=%g, b=%g, poro=%g, perm=%g mD, sigma_costau=%g mN/m\n"
-            % (a, b, poro, perm, sigma_costau)
+            f"-- a={a:g}, b={b:g}, poro={poro:g}, perm={perm:g} mD, "
+            f"sigma_costau={sigma_costau:g} mN/m\n"
         )
 
     def add_skjaeveland_pc(
@@ -862,17 +877,16 @@ class WaterOil(object):
         if sor is None:
             sor = self.sorw
 
-        if swr >= 1 - sor:
-            raise ValueError("swr (swirr) must be less than 1 - sor")
         if swr < 0 or swr > 1:
             raise ValueError("swr must be contained in [0,1]")
         if sor < 0 or sor > 1:
             raise ValueError("sor must be contained in [0,1]")
+        if swr >= 1 - sor:
+            raise ValueError("swr (swirr) must be less than 1 - sor")
 
         self.pccomment = (
             "-- Skjæveland correlation for Pc;\n"
-            + "-- cw=%g, co=%g, aw=%g, ao=%g, swr=%g, sor=%g\n"
-            % (cw, co, aw, ao, swr, sor)
+            f"-- cw={cw:g}, co={co:g}, aw={aw:g}, ao={ao:g}, swr={swr:g}, sor={sor:g}\n"
         )
 
         # swnpc is a normalized saturation, but normalized with
@@ -941,8 +955,9 @@ class WaterOil(object):
         self.table.loc[self.table["SWN"] < epsilon, "PC"] = Pcmax
         self.pccomment = (
             "-- LET correlation for primary drainage Pc;\n"
-            "-- Lp=%g, Ep=%g, Tp=%g, Lt=%g, Et=%g, Tt=%g, Pcmax=%g, Pct=%g\n"
-            % (Lp, Ep, Tp, Lt, Et, Tt, Pcmax, Pct)
+            f"-- Lp={Lp:g}, Ep={Ep:g}, Tp={Tp:g}, "
+            f"Lt={Lt:g}, Et={Et:g}, Tt={Tt:g}, "
+            f"Pcmax={Pcmax:g}, Pct={Pct:g}\n"
         )
 
     def add_LET_pc_imb(
@@ -998,8 +1013,9 @@ class WaterOil(object):
         self.table.loc[self.table["SWNPCO"] > 1 - epsilon, "PC"] = Pcmin
         self.pccomment = (
             "-- LET correlation for imbibition Pc;\n"
-            "-- Ls=%g, Es=%g, Ts=%g, Lf=%g, Ef=%g, Tf=%g, Pcmax=%g, Pcmin=%g, Pct=%g\n"
-            % (Ls, Es, Ts, Lf, Ef, Tf, Pcmax, Pcmin, Pct)
+            f"-- Ls={Ls:g}, Es={Es:g}, Ts={Ts:g}, "
+            f"Lf={Lf:g}, Ef={Ef:g}, Tf={Tf:g}, "
+            f"Pcmax={Pcmax:g}, Pcmin={Pcmin:g}, Pct={Pct:g}\n"
         )
 
     def estimate_sorw(self, curve: str = "KRW") -> float:
@@ -1031,6 +1047,13 @@ class WaterOil(object):
             self.table, xcol="SW", ycol=curve, side="right"
         )
 
+    def estimate_socr(self) -> float:
+        """Estimate socr from the current kro data."""
+        assert self.table["KROW"].sum() > 0
+        return self.table["SW"].max() - estimate_diffjumppoint(
+            self.table, xcol="SW", ycol="KROW", side="right"
+        )
+
     def estimate_swcr(self, curve: str = "KRW") -> float:
         """Estimate swcr of the current krw data.
 
@@ -1161,7 +1184,7 @@ class WaterOil(object):
             string += self.krwcomment
             string += self.krowcomment
             if not self.fast:
-                string += "-- krw = krow @ sw=%1.5f\n" % self.crosspoint()
+                string += f"-- krw = krow @ sw={self.crosspoint():1.5f}\n"
             string += self.pccomment
         width = 10
         string += (
@@ -1232,7 +1255,7 @@ class WaterOil(object):
             string += self.krwcomment
             if crosspointcomment is None:
                 if "KROW" in self.table.columns and not self.fast:
-                    string += "-- krw = krow @ sw=%1.5f\n" % self.crosspoint()
+                    string += f"-- krw = krow @ sw={self.crosspoint():1.5f}\n"
             else:
                 string += crosspointcomment
             string += self.pccomment
@@ -1272,7 +1295,7 @@ class WaterOil(object):
             string += self.krwcomment.replace("--", "!")
             string += self.krowcomment.replace("--", "!")
             if not self.fast:
-                string += "! krw = krow @ sw=%1.5f\n" % self.crosspoint()
+                string += f"! krw = krow @ sw={self.crosspoint():1.5f}\n"
             string += self.pccomment.replace("--", "!")
         width = 10
         string += (
@@ -1312,8 +1335,8 @@ class WaterOil(object):
         """
         # pylint: disable=import-outside-toplevel
         # Lazy import for speed reaons.
-        import matplotlib.pyplot as plt
         import matplotlib
+        import matplotlib.pyplot as plt
 
         if mpl_ax is None:
             matplotlib.style.use("ggplot")
@@ -1355,8 +1378,8 @@ class WaterOil(object):
         the specified axis."""
         # pylint: disable=import-outside-toplevel
         # Lazy import for speed reaons.
-        import matplotlib.pyplot as plt
         import matplotlib
+        import matplotlib.pyplot as plt
 
         if mpl_ax is None:
             matplotlib.style.use("ggplot")
