@@ -1,18 +1,18 @@
 """Container object for one WaterOil and one GasOil object"""
 
-import logging
+from typing import Optional
+
 import numpy as np
 import pandas as pd
-from typing import Optional
 
 import pyscal
 from pyscal.constants import SWINTEGERS
+from pyscal.utils.string import comment_formatter, df2str
 
-from pyscal.utils.string import df2str, comment_formatter
-from .wateroil import WaterOil
 from .gasoil import GasOil
+from .wateroil import WaterOil
 
-logger = logging.getLogger(__name__)
+logger = pyscal.getLogger_pyscal(__name__)
 
 
 class WaterOilGas(object):
@@ -21,14 +21,16 @@ class WaterOilGas(object):
 
     Use one object for each satnum.
 
-    One WaterOil and one GasOil object will be created, with
-    compatible saturation ranges. Access the class members 'wateroil'
-    and 'gasoil' directly to add curves.
+    One WaterOil and one GasOil object will be created, with compatible
+    saturation ranges. Access the class members 'wateroil' and 'gasoil'
+    directly to add curves.
 
-    All arguments to the initializer can be defaulted, and all are zero except h.
+    All arguments to the initializer can be defaulted, and all are zero except
+    h.
 
-    Either the gasoil or the wateroil member is allowed to be None
-    in case of only two phases present.
+    Either the gasoil or the wateroil member is allowed to be None in case of
+    only two phases present. It is allowed for functions to set these members
+    to None after initialization, as done in SCALrecommendation.interpolate()
 
     Args:
         swirr: Irreducible water saturation for capillary pressure
