@@ -4,20 +4,18 @@ from pathlib import Path
 
 import numpy as np
 import pandas as pd
-
 import pytest
 
 from pyscal import (
-    factory,
-    WaterOil,
     GasOil,
     GasWater,
-    WaterOilGas,
     PyscalFactory,
     SCALrecommendation,
+    WaterOil,
+    WaterOilGas,
+    factory,
 )
-
-from pyscal.utils.testing import sat_table_str_ok, check_table
+from pyscal.utils.testing import check_table, sat_table_str_ok
 
 
 def test_factory_wateroil():
@@ -411,7 +409,7 @@ def test_factory_gasoil():
     assert "Zero capillary pressure" in sgof
 
     gasoil = pyscal_factory.create_gas_oil(
-        dict(ng=1.2, nog=2, krgend=0.8, krgmax=0.9, krogend=0.6)
+        dict(ng=1.2, nog=2, krgend=0.8, krgmax=0.9, kroend=0.6)
     )
     sgof = gasoil.SGOF()
     sat_table_str_ok(sgof)
@@ -615,24 +613,12 @@ def test_factory_wateroilgas():
     assert wateroil.gasoil is None
 
 
-def test_factory_wateroilgas_deprecated_krowgend(caplog):
-    """Some users will use deprecated  krowend krogend,
-    these values should be translated to kroend"""
-    wog = PyscalFactory.create_water_oil_gas(
-        dict(nw=2, now=3, ng=1, nog=2.5, krowend=0.6, krogend=0.7)
-    )
-    assert "deprecated" in caplog.text
-    swof = wog.SWOF()
-    assert "kroend=0.6" in swof
-    sgof = wog.SGOF()
-    assert "kroend=0.7" in sgof
-    assert not wog.threephaseconsistency()
-    sat_table_str_ok(swof)  # sgof code works for swof also currently
-    sat_table_str_ok(sgof)
-    assert "Corey krg" in sgof
-    assert "Corey krog" in sgof
-    assert "Corey krw" in swof
-    assert "Corey krow" in swof
+def test_factory_wateroilgas_deprecated_krowgend():
+    """Using long-time deprecated krowend and krogend will fail"""
+    with pytest.raises(ValueError):
+        PyscalFactory.create_water_oil_gas(
+            dict(nw=2, now=3, ng=1, nog=2.5, krowend=0.6, krogend=0.7)
+        )
 
 
 def test_factory_wateroilgas_wo():
@@ -651,7 +637,39 @@ def test_factory_wateroilgas_wo():
     wog.SGOF()
 
 
-def test_load_relperm_df(tmpdir, caplog):
+def test_factory_wateroil_paleooil(caplog):
+    """Test making a WaterOil object with socr different from sorw."""
+    pyscal_factory = PyscalFactory()
+    sorw = 0.09
+    wateroil = pyscal_factory.create_water_oil(
+        dict(nw=2, now=3, kroend=0.5, sorw=sorw, socr=sorw + 0.01, swcr=0.1)
+    )
+    swof = wateroil.SWOF()
+    assert "Corey krw" in swof
+    assert "socr=0.1" in swof
+    sat_table_str_ok(swof)
+    check_table(wateroil.table)
+
+    # If socr is close to sorw, socr is reset to sorw.
+    for socr in [sorw - 1e-9, sorw, sorw + 1e-9]:
+        wo_socrignored = pyscal_factory.create_water_oil(
+            dict(nw=2, now=3, kroend=0.5, sorw=0.09, socr=socr, swcr=0.1)
+        )
+        swof = wo_socrignored.SWOF()
+        assert "socr" not in swof  # socr is effectively ignored when = sorw.
+        sat_table_str_ok(swof)
+        if socr != sorw:
+            # This warning should only occur when it seems like the user
+            # has tried to explicitly set socr
+            assert "socr was close to sorw, reset to sorw" in caplog.text
+
+    with pytest.raises(ValueError, match="socr must be equal to or larger than sorw"):
+        pyscal_factory.create_water_oil(
+            dict(nw=2, now=3, kroend=0.5, sorw=0.09, socr=0.001, swcr=0.1, h=0.1)
+        )
+
+
+def test_load_relperm_df(tmp_path, caplog):
     """Test loading of dataframes with validation from excel or from csv"""
     testdir = Path(__file__).absolute().parent
 
@@ -668,7 +686,7 @@ def test_load_relperm_df(tmpdir, caplog):
     assert "CASE" in scaldata
     assert not scaldata.empty
 
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     scaldata.to_csv("scal-input.csv")
     scaldata_fromcsv = PyscalFactory.load_relperm_df("scal-input.csv")
     assert "CASE" in scaldata_fromcsv
@@ -723,18 +741,21 @@ def test_load_relperm_df(tmpdir, caplog):
     assert "foobar" in swof_str  # Random string injected in xlsx.
 
     # Make a dummy text file
-    Path("dummy.txt").write_text("foo\nbar, com")
+    Path("dummy.txt").write_text("foo\nbar, com", encoding="utf8")
     with pytest.raises(ValueError):
         PyscalFactory.load_relperm_df("dummy.txt")
 
     # Make an empty csv file
-    Path("empty.csv").write_text("")
-    # A ValueError would also make sense here
-    assert PyscalFactory.load_relperm_df("empty.csv").empty
+    Path("empty.csv").write_text("", encoding="utf8")
+    with pytest.raises(ValueError, match="Impossible to infer file format"):
+        PyscalFactory.load_relperm_df("empty.csv")
+
+    with pytest.raises(ValueError, match="SATNUM must be present"):
+        PyscalFactory.load_relperm_df(pd.DataFrame())
 
     # Merge tags and comments if both are supplied
     Path("tagandcomment.csv").write_text(
-        "SATNUM,nw,now,tag,comment\n1,1,1,a-tag,a-comment"
+        "SATNUM,nw,now,tag,comment\n1,1,1,a-tag,a-comment", encoding="utf8"
     )
     tagandcomment_df = PyscalFactory.load_relperm_df("tagandcomment.csv")
     assert (
@@ -742,20 +763,20 @@ def test_load_relperm_df(tmpdir, caplog):
     )
 
     # Missing SATNUMs:
-    Path("wrongsatnum.csv").write_text("SATNUM,nw,now\n1,1,1\n3,1,1")
+    Path("wrongsatnum.csv").write_text("SATNUM,nw,now\n1,1,1\n3,1,1", encoding="utf8")
     with pytest.raises(ValueError, match="Missing SATNUMs?"):
         PyscalFactory.load_relperm_df("wrongsatnum.csv")
 
     # Missing SATNUMs, like merged cells:
     Path("mergedcells.csv").write_text(
-        "CASE,SATNUM,nw,now\nlow,,1,1\nlow,1,2,2\nlow,,3,32"
+        "CASE,SATNUM,nw,now\nlow,,1,1\nlow,1,2,2\nlow,,3,32", encoding="utf8"
     )
     with pytest.raises(ValueError, match="Found not-a-number"):
         PyscalFactory.load_relperm_df("mergedcells.csv")
 
     # Missing SATNUMs, like merged cells:
     Path("mergedcellscase.csv").write_text(
-        "CASE,SATNUM,nw,now\n,1,1,1\nlow,1,2,2\n,1,3,32"
+        "CASE,SATNUM,nw,now\n,1,1,1\nlow,1,2,2\n,1,3,32", encoding="utf8"
     )
     with pytest.raises(ValueError, match="Found not-a-number"):
         PyscalFactory.load_relperm_df("mergedcellscase.csv")
@@ -805,16 +826,52 @@ def test_xls_factory():
         assert "LET krog" in sgof
 
 
-def test_create_lists():
-    """Test the factory methods for making pyscal lists"""
+def test_create_scal_recommendation_list():
+    """Test the factory methods for making scalrecommendation lists"""
     testdir = Path(__file__).absolute().parent
-
     scalfile_xls = testdir / "data/scal-pc-input-example.xlsx"
     scaldata = PyscalFactory.load_relperm_df(scalfile_xls)
+
     scalrec_list = PyscalFactory.create_scal_recommendation_list(scaldata)
     assert len(scalrec_list) == 3
     assert scalrec_list.pyscaltype == SCALrecommendation
 
+    # Erroneous input:
+    with pytest.raises(ValueError, match="Too many cases supplied for SATNUM 2"):
+        PyscalFactory.create_scal_recommendation_list(
+            pd.DataFrame(
+                columns=["SATNUM", "CASE", "NW", "NOW"],
+                data=[
+                    [1, "low", 1, 1],
+                    [1, "base", 2, 2],
+                    [1, "high", 3, 3],
+                    [2, "low", 1, 1],
+                    [2, "nearlylow", 1.4, 1.2],
+                    [2, "base", 2, 2],
+                    [2, "high", 3, 3],
+                ],
+            )
+        )
+    with pytest.raises(ValueError, match="Too few cases supplied for SATNUM 2"):
+        PyscalFactory.create_scal_recommendation_list(
+            pd.DataFrame(
+                columns=["SATNUM", "CASE", "NW", "NOW"],
+                data=[
+                    [1, "low", 1, 1],
+                    [1, "base", 2, 2],
+                    [1, "high", 3, 3],
+                    [2, "low", 1, 1],
+                    [2, "high", 3, 3],
+                ],
+            )
+        )
+
+
+def test_create_pyscal_list():
+    """Test the factory methods for making pyscal lists"""
+    testdir = Path(__file__).absolute().parent
+    scalfile_xls = testdir / "data/scal-pc-input-example.xlsx"
+    scaldata = PyscalFactory.load_relperm_df(scalfile_xls)
     basecasedata = scaldata[scaldata["CASE"] == "base"].reset_index()
     relpermlist = PyscalFactory.create_pyscal_list(basecasedata)
     assert len(relpermlist) == 3
@@ -834,6 +891,20 @@ def test_create_lists():
     assert len(go_list) == 3
     assert go_list.pyscaltype == GasOil
 
+    gw_list = PyscalFactory.create_pyscal_list(
+        basecasedata.drop(["Low", "Eow", "Tow", "Log", "Eog", "Tog"], axis="columns")
+    )
+
+    assert len(gw_list) == 3
+    assert gw_list.pyscaltype == GasWater
+
+    with pytest.raises(
+        ValueError, match="Could not determine two or three phase from parameters"
+    ):
+        PyscalFactory.create_pyscal_list(
+            basecasedata.drop(["Ew", "Eg"], axis="columns")
+        )
+
 
 def test_scalrecommendation():
     """Testing making SCAL rec from dict of dict."""
@@ -887,6 +958,14 @@ def test_scalrecommendation():
     with pytest.raises(ValueError, match='"high" case not supplied'):
         pyscal_factory.create_scal_recommendation(baselow)
 
+    with pytest.raises(
+        ValueError, match="All values in parameter dict must be dictionaries"
+    ):
+
+        pyscal_factory.create_scal_recommendation(
+            {"low": [1, 2], "base": {"swl": 0.1}, "high": {"swl": 0.1}}
+        )
+
 
 def test_scalrecommendation_gaswater():
     """Testing making SCAL rec from dict of dict for gaswater input"""
@@ -928,20 +1007,30 @@ def test_no_gasoil():
         PyscalFactory.load_relperm_df(dframe)
 
 
-def test_check_deprecated_krowgend(caplog):
+def test_check_deprecated_krowgend():
     """Up until pyscal 0.5.x, krogend and krowend were parameters
     to the oil curve parametrization for WaterOil and GasOil. From
     pyscal 0.6.0, krogend and krowend are merged to kroend.
+    After pyscal 0.8 presence of krogend and krowend is a ValueError
     """
-    wateroil = PyscalFactory.create_water_oil(dict(swl=0.1, nw=2, now=2, krowend=0.4))
-    assert "krowend" in caplog.text
-    assert "deprecated" in caplog.text
-    assert wateroil.table["KROW"].max() == 0.4
+    with pytest.raises(ValueError):
+        PyscalFactory.create_water_oil(dict(swl=0.1, nw=2, now=2, krowend=0.4))
 
-    gasoil = PyscalFactory.create_gas_oil(dict(swl=0.1, ng=2, nog=2, krogend=0.4))
-    assert "krogend" in caplog.text
-    assert "deprecated" in caplog.text
-    assert gasoil.table["KROG"].max() == 0.4
+    with pytest.raises(ValueError):
+        PyscalFactory.create_gas_oil(dict(swl=0.1, ng=2, nog=2, krogend=0.4))
+
+    # If krogend and kroend are both present, krogend is to be silently ignored
+    # (random columns are in general accepted and ignored by pyscal)
+
+    gasoil = PyscalFactory.create_gas_oil(
+        dict(swl=0.1, ng=2, nog=2, krogend=0.4, kroend=0.3)
+    )
+    assert gasoil.table["KROG"].max() == 0.3
+
+    wateroil = PyscalFactory.create_water_oil(
+        dict(swl=0.1, nw=2, now=2, krowend=0.4, kroend=0.3)
+    )
+    assert wateroil.table["KROW"].max() == 0.3
 
 
 def parse_gensatfuncline(conf_line):
@@ -1042,7 +1131,7 @@ def test_sufficient_params():
     with pytest.raises(ValueError):
         factory.sufficient_gas_oil_params({"ng": 0}, failhard=True)
     assert not factory.sufficient_gas_oil_params({"ng": 0}, failhard=False)
-    assert not factory.sufficient_gas_oil_params(dict())
+    assert not factory.sufficient_gas_oil_params({})
     with pytest.raises(ValueError):
         factory.sufficient_gas_oil_params({"lg": 0}, failhard=True)
     assert not factory.sufficient_gas_oil_params({"lg": 0}, failhard=False)
@@ -1053,7 +1142,7 @@ def test_sufficient_params():
     assert factory.sufficient_water_oil_params({"nw": 0, "now": 0})
     with pytest.raises(ValueError):
         factory.sufficient_water_oil_params({"nw": 0}, failhard=True)
-    assert not factory.sufficient_water_oil_params(dict())
+    assert not factory.sufficient_water_oil_params({})
     with pytest.raises(ValueError):
         factory.sufficient_water_oil_params({"lw": 0}, failhard=True)
     assert factory.sufficient_water_oil_params(
@@ -1150,7 +1239,20 @@ def test_case_aliasing():
         )
 
 
-def test_swirr_partially_missing(tmpdir):
+def test_socr_via_dframe():
+    """Test that the "socr" parameter is picked up from a dataframe/xlsx input"""
+    p_list = PyscalFactory.create_pyscal_list(
+        PyscalFactory.load_relperm_df(
+            pd.DataFrame(
+                columns=["SATNUM", "Nw", "Now", "socr"],
+                data=[[1, 2, 2, 0.5]],
+            )
+        )
+    )
+    assert "socr=0.5" in p_list.SWOF()
+
+
+def test_swirr_partially_missing(tmp_path):
     """Test that swirr can be present for only a subset of the rows,
     and interpreted as zero when not there."""
     dframe = pd.DataFrame(
@@ -1176,7 +1278,7 @@ def test_swirr_partially_missing(tmpdir):
     assert "a=2, b=-2" in p_list[1].pccomment
     assert p_list[2].pccomment == ""
 
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     dframe.to_excel("partial_pc.xlsx")
     relperm_data_via_xlsx = PyscalFactory.load_relperm_df("partial_pc.xlsx")
     p_list = PyscalFactory.create_pyscal_list(relperm_data_via_xlsx, h=0.2)
@@ -1201,8 +1303,8 @@ def test_corey_let_mix():
     assert "Corey krow" in swof2
 
 
-def test_infer_tabular_file_format(tmpdir, caplog):
-
+def test_infer_tabular_file_format(tmp_path, caplog):
+    """Test code that infers the fileformat of files with tabular data"""
     testdir = Path(__file__).absolute().parent
     assert (
         factory.infer_tabular_file_format(testdir / "data/scal-pc-input-example.xlsx")
@@ -1218,16 +1320,14 @@ def test_infer_tabular_file_format(tmpdir, caplog):
         factory.infer_tabular_file_format(testdir / "data/scal-pc-input-example.xls")
         == "xls"
     )
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     pd.DataFrame([{"SATNUM": 1, "NW": 2}]).to_csv("some.csv", index=False)
     assert factory.infer_tabular_file_format("some.csv") == "csv"
 
-    Path("empty.csv").write_text("")
+    Path("empty.csv").write_text("", encoding="utf8")
     assert factory.infer_tabular_file_format("empty.csv") == ""
     # Ensure Pandas's error message got through:
     assert "No columns to parse from file" in caplog.text
-    # Ensure factory.py's error message got through:
-    assert "Impossible to infer file format for empty.csv" in caplog.text
 
     # We don't want ISO-8859 files, ensure we fail
     norw_chars = "Dette,er,en,CSV,fil\nmed,iso-8859:,æ,ø,å"
@@ -1242,7 +1342,6 @@ def test_infer_tabular_file_format(tmpdir, caplog):
     # little probability give a valid xlsx/xls/csv file.
     Path("wrong.csv").write_bytes(os.urandom(100))
     assert factory.infer_tabular_file_format("wrong.csv") == ""
-    assert "Impossible to infer file format for wrong.csv" in caplog.text
 
 
 @pytest.mark.parametrize(
@@ -1256,4 +1355,5 @@ def test_infer_tabular_file_format(tmpdir, caplog):
     ],
 )
 def test_slicedict(orig_dict, keylist, expected_dict):
+    """Test that dictionaries can be sliced for subsets"""
     assert factory.slicedict(orig_dict, keylist) == expected_dict
