@@ -1,25 +1,23 @@
 """Test module for GasOil objects"""
 import io
+import sys
 
-import numpy as np
-import pandas as pd
-
+import hypothesis.strategies as st
 import matplotlib
 import matplotlib.pyplot
-
+import numpy as np
+import pandas as pd
 import pytest
-
-from hypothesis import given, settings
-import hypothesis.strategies as st
+from hypothesis import given
 
 from pyscal import GasOil
-from pyscal.constants import SWINTEGERS
-
+from pyscal.constants import MAX_EXPONENT, SWINTEGERS
+from pyscal.utils.relperm import truncate_zeroness
 from pyscal.utils.testing import (
-    float_df_checker,
-    check_table,
-    sat_table_str_ok,
     check_linear_sections,
+    check_table,
+    float_df_checker,
+    sat_table_str_ok,
 )
 
 
@@ -49,6 +47,10 @@ def test_gasoil_init():
     assert isinstance(gasoil, GasOil)
     assert gasoil.krgendanchor == ""
 
+    gasoil = GasOil(krgendanchor=None)
+    assert isinstance(gasoil, GasOil)
+    assert gasoil.krgendanchor == ""
+
     # Test with h=1
     gasoil = GasOil(h=1)
     gasoil.add_corey_gas()
@@ -70,6 +72,28 @@ def test_gasoil_init():
     assert gasoil.h == 1 / SWINTEGERS
 
 
+def test_conserve_sgcr(mocker):
+    """sgcr in the table can be hard to conserve"""
+    low_sgcrvalue = 0.00001  # 1/10 of 1/SWINTEGERS
+    # Verify the default behaviour of truncation:
+    assert truncate_zeroness(low_sgcrvalue) == 0
+    mocker.patch(
+        # Remove the effect of zeroness truncation in order to provoke
+        # the safeguarding measures for sgcr.
+        "pyscal.gasoil.truncate_zeroness",
+        return_value=low_sgcrvalue,
+    )
+    gasoil = GasOil(swl=0, sgcr=low_sgcrvalue, h=0.2)
+    assert gasoil.sgcr == low_sgcrvalue  # To check that we have not truncated it away
+    assert gasoil.table["SG"][0] == 0
+    assert gasoil.table["SG"][1] == low_sgcrvalue
+
+    gasoil.add_corey_gas()
+    gasoil.add_corey_oil()
+    assert gasoil.selfcheck()
+    assert "SGOF" in gasoil.SGOF()
+
+
 def test_errors():
     """Test some error situations for the constructor"""
     with pytest.raises(ValueError, match="No saturation range left"):
@@ -78,19 +102,36 @@ def test_errors():
         GasOil(swl=0.3, sgro=0.88, sgcr=0.88)
     with pytest.raises(ValueError, match="No saturation range left"):
         GasOil(swl=0.3, sgcr=0.88)
+
+    # This only raises error if krgendanchor is non-default:
+    GasOil(swl=0.3, sgcr=0.4, sorg=0.4, krgendanchor="")
+    with pytest.raises(ValueError, match="No saturation range left"):
+        GasOil(swl=0.3, sgcr=0.4, sorg=0.4)
+
+    with pytest.raises(ValueError, match="No saturation range left"):
+        GasOil(swl=0.3, sgcr=0.8, sorg=0.4, krgendanchor="")
+
+    with pytest.raises(ValueError, match="No saturation range left"):
+        GasOil(swl=0.3, sgcr=0.88, krgendanchor="")
     with pytest.raises(ValueError, match="sgro must be zero or equal to sgcr"):
         GasOil(swl=0.3, sgcr=0.1, sgro=0.2)
 
+    with pytest.raises(ValueError, match="sgro must be zero or equal to sgcr"):
+        GasOil(swl=0.4, sorg=0.4, sgro=0.4)
 
-def test_plotting():
+
+@pytest.mark.skipif(sys.platform == "win32", reason="Plotting not stable on windows")
+def test_plotting(mocker):
     """Test that plotting code pass through (nothing displayed)"""
+    mocker.patch("matplotlib.pyplot.show", return_value=None)
     gasoil = GasOil(swl=0.1, h=0.1)
     gasoil.add_corey_gas()
     gasoil.add_corey_oil()
     gasoil.plotkrgkrog(mpl_ax=matplotlib.pyplot.subplots()[1])
+    gasoil.plotkrgkrog(mpl_ax=None)
+    gasoil.plotkrgkrog(logyscale=True, mpl_ax=None)
 
 
-@settings(deadline=300)
 @given(st.text())
 def test_gasoil_tag(tag):
     """Test tagging of GasOil objects,
@@ -103,7 +144,6 @@ def test_gasoil_tag(tag):
     sat_table_str_ok(gasoil.SGFN())
 
 
-@settings(deadline=500)
 @given(
     st.floats(min_value=0, max_value=0.15),  # swl
     st.floats(min_value=0, max_value=0.3),  # sgcr
@@ -123,7 +163,9 @@ def test_gasoil_normalization(swl, sgcr, sorg, h, tag):
     # Check that son is 1 at sg=0
     assert float_df_checker(gasoil.table, "SG", 0, "SON", 1)
 
-    # Check that son is 0 at sorg with this krgendanchor
+    # Check that son is 0 at sorg with this krgendanchor.
+    # It is important to use the endpoints from the returned gasoil
+    # object, as they can be modified in case they are too close to zero.
     assert float_df_checker(gasoil.table, "SG", 1 - gasoil.sorg - gasoil.swl, "SON", 0)
 
     # Check that sgn is 0 at sgcr
@@ -140,7 +182,6 @@ def test_gasoil_normalization(swl, sgcr, sorg, h, tag):
     assert float_df_checker(gasoil.table, "SG", gasoil.sgcr, "SGN", 0)
 
 
-@settings(deadline=1000)
 @given(
     st.floats(min_value=0, max_value=0.3),  # swl
     st.floats(min_value=0, max_value=0.3),  # sgcr
@@ -150,7 +191,7 @@ def test_gasoil_normalization(swl, sgcr, sorg, h, tag):
     st.floats(min_value=0.1, max_value=1),  # kromax
     st.floats(min_value=0.1, max_value=1),  # krgend
     st.floats(min_value=0.2, max_value=1),  # krgmax
-    st.floats(min_value=0.0001, max_value=1),  # h
+    st.floats(min_value=0.001, max_value=0.5),  # h
     st.booleans(),  # fast mode
 )
 def test_gasoil_krendmax(
@@ -174,6 +215,7 @@ def test_gasoil_krendmax(
     check_table(gasoil.table)
     check_linear_sections(gasoil)
     assert gasoil.selfcheck()
+    sat_table_str_ok(gasoil.SGOF())
     check_endpoints(gasoil, krgend, krgmax, kroend, kromax)
     assert 0 < gasoil.crosspoint() < 1
 
@@ -203,13 +245,14 @@ def check_endpoints(gasoil, krgend, krgmax, kroend, kromax):
     swtol = 1 / SWINTEGERS
 
     # Oil curve, from sg = 0 to sg = 1:
-    if gasoil.sgro < swtol:
-        assert float_df_checker(gasoil.table, "SG", 0, "KROG", kroend)
-        assert np.isclose(gasoil.table["KROG"].max(), kroend)
-    else:
+    if gasoil.sgro > 0:
+        # Gas-condensate: sgcr = sgro > 0
         assert float_df_checker(gasoil.table, "SG", 0, "KROG", kromax)
         assert float_df_checker(gasoil.table, "SON", 1.0, "KROG", kroend)
         assert np.isclose(gasoil.table["KROG"].max(), kromax)
+    else:
+        assert float_df_checker(gasoil.table, "SG", 0, "KROG", kroend)
+        assert np.isclose(gasoil.table["KROG"].max(), kroend)
 
     # son=0 @ 1 - sorg - swl or 1 - swl) should be zero:
     assert float_df_checker(gasoil.table, "SON", 0.0, "KROG", 0)
@@ -231,6 +274,24 @@ def check_endpoints(gasoil, krgend, krgmax, kroend, kromax):
     assert np.isclose(gasoil.table["KRG"].min(), 0.0)
 
 
+def test_sgro_vs_sgcr():
+    """Test that a sgro that is close enough to sgcr does not cause problems"""
+    with pytest.raises(ValueError, match="sgro must be zero or equal to sgcr"):
+        GasOil(sgcr=0.1, sgro=0.1 + 1e-7, h=0.01)
+    with pytest.raises(ValueError, match="sgro must be zero or equal to sgcr"):
+        GasOil(sgcr=0.1, sgro=0.1 - 1e-7, h=0.01)
+
+    # This is close enough to sgcr:
+    gasoil = GasOil(sgcr=0.1, sgro=0.1 + 1e-8, h=0.01)
+    gasoil.add_corey_oil(nog=2, kroend=0.5, kromax=1)
+
+    # KROG should not be affected at sg=0.1, even if sgro is "larger":
+    assert float_df_checker(gasoil.table, "SG", 0.0, "KROG", 1.0)
+    assert float_df_checker(gasoil.table, "SG", 0.1, "KROG", 0.5)
+    assert gasoil.table["SG"][0] == 0
+    assert gasoil.table["SG"][1] == 0.1
+
+
 def test_gasoil_krgendanchor():
     """Test behaviour of the krgendanchor"""
     gasoil = GasOil(krgendanchor="sorg", sorg=0.2, h=0.1)
@@ -296,7 +357,7 @@ def test_nexus():
     gasoil.add_corey_gas(ng=10, krgend=0.5)
     nexus_lines = gasoil.GOTABLE().splitlines()
     non_comments = [
-        line for line in nexus_lines if not line.startswith("!") or not len(line)
+        line for line in nexus_lines if not line.startswith("!") or not line
     ]
     assert non_comments[0] == "GOTABLE"
     assert non_comments[1] == "SG KRG KROG PC"
@@ -306,6 +367,7 @@ def test_nexus():
         sep=r"\s+",
         header=None,
     )
+    # pylint: disable=no-member  # false positive on Pandas dataframe
     assert (df.values <= 1.0).all()
     assert (df.values >= 0.0).all()
 
@@ -338,8 +400,10 @@ def test_kroend():
     assert gasoil.table["KROG"].max() == 0.5
 
 
-@settings(deadline=1500)
-@given(st.floats(), st.floats())
+@given(
+    st.floats(min_value=1e-4, max_value=MAX_EXPONENT),  # ng
+    st.floats(min_value=1e-4, max_value=MAX_EXPONENT),  # nog
+)
 def test_gasoil_corey1(ng, nog):
     """Test the Corey formulation for gasoil"""
     gasoil = GasOil()
@@ -358,7 +422,7 @@ def test_gasoil_corey1(ng, nog):
     assert len(sgofstr) > 100
     sat_table_str_ok(sgofstr)
 
-    gasoil.resetsorg()
+    gasoil.update_sgcomment_and_sorg()
     check_table(gasoil.table)
     check_linear_sections(gasoil)
     sgofstr = gasoil.SGOF()
@@ -406,7 +470,6 @@ def test_comments():
     assert "PC" in sgof
 
 
-@settings(deadline=1500)
 @given(st.floats(), st.floats(), st.floats(), st.floats(), st.floats())
 def test_gasoil_let1(l, e, t, krgend, krgmax):
     """Test the LET formulation, take 1"""
@@ -521,6 +584,7 @@ def test_roundoff():
         ("SG", [0, 2]),
         ("KRG", [1, 0]),
         ("KRG", [0, 2]),
+        ("KRG", [1, 2]),
         ("KROG", [0, 1]),
         ("KROG", [2, 0]),
         ("PC", [np.inf, 0]),
