@@ -5,16 +5,14 @@ instructions for what to check."""
 
 import random
 
-import numpy as np
-
-from matplotlib import pyplot
 import matplotlib
-
+import numpy as np
 import pytest
+from matplotlib import pyplot
 
-from pyscal import WaterOil, GasOil, GasWater, utils, PyscalFactory
+from pyscal import GasOil, GasWater, PyscalFactory, WaterOil, utils
 
-from .test_scalrecommendation import LOW_SAMPLE_LET, BASE_SAMPLE_LET, HIGH_SAMPLE_LET
+from .test_scalrecommendation import BASE_SAMPLE_LET, HIGH_SAMPLE_LET, LOW_SAMPLE_LET
 
 
 @pytest.mark.plot
@@ -96,11 +94,13 @@ def test_interpolate_wo():
     swl_l = random.uniform(0, 0.1)
     swcr_l = swl_l + random.uniform(0, 0.1)
     sorw_l = random.uniform(0, 0.2)
+    socr_l = sorw_l + random.uniform(0, 0.3)
     swl_h = random.uniform(0, 0.1)
     swcr_h = swl_h + random.uniform(0, 0.1)
     sorw_h = random.uniform(0, 0.2)
-    wo_low = WaterOil(swl=swl_l, swcr=swcr_l, sorw=sorw_l, h=0.001)
-    wo_high = WaterOil(swl=swl_h, swcr=swcr_h, sorw=sorw_h, h=0.001)
+    socr_h = sorw_h + random.uniform(0, 0.3)
+    wo_low = WaterOil(swl=swl_l, swcr=swcr_l, sorw=sorw_l, socr=socr_l, h=0.001)
+    wo_high = WaterOil(swl=swl_h, swcr=swcr_h, sorw=sorw_h, socr=socr_h, h=0.001)
     wo_low.add_corey_water(nw=random.uniform(1, 3), krwend=random.uniform(0.5, 1))
     wo_high.add_corey_water(nw=random.uniform(1, 3), krwend=random.uniform(0.5, 1))
     wo_low.add_corey_oil(now=random.uniform(1, 3), kroend=random.uniform(0.5, 1))
@@ -310,6 +310,7 @@ def test_interpolate_gw():
 @pytest.mark.plot
 def test_SCAL_interpolation():
     """Demonstration of interpolation between LET curves, 2x2 subplot"""
+    # pylint: disable=invalid-name
     matplotlib.style.use("ggplot")
 
     rec = PyscalFactory.create_scal_recommendation(
@@ -425,8 +426,8 @@ def test_letspan():
     }
 
     # We need sorted versions for the random function
-    slimw = {x: sorted(let_w[x]) for x in let_w}
-    slimo = {x: sorted(let_o[x]) for x in let_o}
+    slimw = {x: sorted(value) for x, value in let_w.items()}
+    slimo = {x: sorted(value) for x, value in let_o.items()}
 
     _, mpl_ax = pyplot.subplots()
     for _ in range(100):
