@@ -4,19 +4,17 @@ from pathlib import Path
 
 import numpy as np
 import pandas as pd
-
 import pytest
 
 from pyscal import (
-    WaterOil,
     GasOil,
     GasWater,
-    WaterOilGas,
     PyscalFactory,
     PyscalList,
     SCALrecommendation,
+    WaterOil,
+    WaterOilGas,
 )
-
 from pyscal.utils.testing import sat_table_str_ok
 
 try:
@@ -63,7 +61,7 @@ def test_pyscallist_basic():
     assert len(p_list) == 3
 
     with pytest.raises(ValueError, match="Not a pyscal object"):
-        PyscalList([dict()])
+        PyscalList([{}])
 
     init_from_list = PyscalList([WaterOil(), WaterOil()])
     assert len(init_from_list) == 2
@@ -72,7 +70,7 @@ def test_pyscallist_basic():
     assert len(init_from_itself) == 2
 
 
-def test_load_scalrec(tmpdir):
+def test_load_scalrec():
     """Load a SATNUM range from xlsx"""
     testdir = Path(__file__).absolute().parent
 
@@ -94,9 +92,9 @@ def test_load_scalrec(tmpdir):
     assert wog_list.pyscaltype == WaterOilGas
 
     with pytest.raises(TypeError):
-        scalrec_list.dump_family_1()
+        scalrec_list.build_eclipse_data(family=1)
     with pytest.raises(TypeError):
-        scalrec_list.dump_family_2()
+        scalrec_list.build_eclipse_data(family=2)
     with pytest.raises(TypeError):
         scalrec_list.SWOF()
 
@@ -104,24 +102,36 @@ def test_load_scalrec(tmpdir):
     with pytest.raises((AssertionError, ValueError)):
         scalrec_list.interpolate([-1, 0, 1.1])
 
-    # Not enough interpolation parameters
-    with pytest.raises(ValueError):
-        scalrec_list.interpolate([-1, 1])
-    with pytest.raises(ValueError):
-        scalrec_list.interpolate([-1, 1, 0, 0])
+    with pytest.raises(
+        TypeError, match="Can only interpolate PyscalList of type SCALrecommendation"
+    ):
+        wog_list.interpolate(-0.5)
 
     scalrec_list.interpolate(-1, 1)
     scalrec_list.interpolate(-1, [0, -1, 1])
 
-    with pytest.raises(ValueError):
+    with pytest.raises(
+        ValueError, match="Too few interpolation parameters given for WaterOil"
+    ):
+        scalrec_list.interpolate([-1, 1])
+    with pytest.raises(
+        ValueError, match="Too few interpolation parameters given for GasOil"
+    ):
+        scalrec_list.interpolate(1, [-1, 1])
+    with pytest.raises(
+        ValueError, match="Too many interpolation parameters given for WaterOil"
+    ):
+        scalrec_list.interpolate([-1, 1, 0, 0])
+    with pytest.raises(
+        ValueError, match="Too many interpolation parameters given for GasOil"
+    ):
         scalrec_list.interpolate(1, [-1, 1, 0, 0])
 
-    # Test slicing the scalrec to base, this is relevant for
-    # API usage.
+    # Test slicing the scalrec to base, this is relevant for API usage.
     base_data = scalrec_data[scalrec_data["CASE"] == "base"].drop("CASE", axis=1)
     PyscalFactory.load_relperm_df(base_data)  # Ensure no errors.
     pyscal_list = PyscalFactory.create_pyscal_list(base_data)
-    assert "LET" in pyscal_list.dump_family_1()
+    assert "LET" in pyscal_list.build_eclipse_data(family=1)
 
 
 def test_df():
@@ -194,8 +204,8 @@ def test_df():
     # WaterOil list
     input_dframe = pd.DataFrame(columns=["SATNUM", "Nw", "Now"], data=[[1, 2, 2]])
     relperm_data = PyscalFactory.load_relperm_df(input_dframe)
-    p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
-    dframe = p_list.df()
+    wo_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
+    dframe = wo_list.df()
     assert "SW" in dframe
     assert "KRW" in dframe
     assert "KROW" in dframe
@@ -207,8 +217,8 @@ def test_df():
     # GasOil list
     input_dframe = pd.DataFrame(columns=["SATNUM", "Ng", "Nog"], data=[[1, 2, 2]])
     relperm_data = PyscalFactory.load_relperm_df(input_dframe)
-    p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
-    dframe = p_list.df()
+    go_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
+    dframe = go_list.df()
     assert "SG" in dframe
     assert "KRG" in dframe
     assert "KROG" in dframe
@@ -217,6 +227,12 @@ def test_df():
     assert len(dframe.columns) == 4
     assert not dframe.empty
 
+    gasoil_family1 = go_list.build_eclipse_data(family=1)
+    assert "SGOF" in gasoil_family1
+
+    with pytest.raises(ValueError, match="SLGOF not meaningful for GasOil"):
+        go_list.build_eclipse_data(family=1, slgof=True)
+
 
 def test_load_scalrec_tags():
     """Test tag handling for a SCAL recommendation with SATNUM range"""
@@ -278,8 +294,9 @@ def test_load_scalrec_tags():
         assert swof.count(tag) == 1
 
 
-def test_dump():
-    """Test dumping Eclipse include data to file"""
+def test_deprecated_dump_to_file(tmpdir):
+    """Test dumping Eclipse include data to file. This
+    functionality is deprecated in pyscallist"""
     testdir = Path(__file__).absolute().parent
 
     relperm_data = PyscalFactory.load_relperm_df(
@@ -287,15 +304,28 @@ def test_dump():
     )
     pyscal_list = PyscalFactory.create_pyscal_list(relperm_data)
 
-    fam1 = pyscal_list.dump_family_1()
+    fam1 = pyscal_list.build_eclipse_data(family=1)
     sat_table_str_ok(fam1)
 
-    fam2 = pyscal_list.dump_family_2()
+    fam2 = pyscal_list.build_eclipse_data(family=2)
     sat_table_str_ok(fam2)
 
     # Empty PyscalLists should return empty strings:
-    assert PyscalList().dump_family_1() == ""
-    assert PyscalList().dump_family_2() == ""
+    assert PyscalList().build_eclipse_data(family=1) == ""
+    assert PyscalList().build_eclipse_data(family=2) == ""
+
+    tmpdir.chdir()
+    with pytest.warns(DeprecationWarning):
+        pyscal_list.dump_family_1(filename="outputdir/output-fam1.inc")
+    assert "SWOF" in Path("outputdir/output-fam1.inc").read_text(encoding="utf8")
+
+    with pytest.warns(DeprecationWarning):
+        pyscal_list.dump_family_2(filename="anotherdir/output-fam2.inc")
+    assert "SOF3" in Path("anotherdir/output-fam2.inc").read_text(encoding="utf8")
+
+    with pytest.warns(DeprecationWarning):
+        pyscal_list.SWOF(write_to_filename="swof.inc")
+    assert "SWOF" in Path("swof.inc").read_text(encoding="utf8")
 
 
 def test_capillary_pressure():
@@ -317,7 +347,7 @@ def test_capillary_pressure():
     pyscal_list = PyscalFactory.create_pyscal_list(
         PyscalFactory.load_relperm_df(dframe)
     )
-    swof = pyscal_list.dump_family_1()
+    swof = pyscal_list.build_eclipse_data(family=1)
     assert "Simplified J-function" in swof
     assert "petrophysical" not in swof
 
@@ -338,7 +368,7 @@ def test_capillary_pressure():
     pyscal_list = PyscalFactory.create_pyscal_list(
         PyscalFactory.load_relperm_df(dframe)
     )
-    swof = pyscal_list.dump_family_1()
+    swof = pyscal_list.build_eclipse_data(family=1)
     assert "Simplified J-function" in swof
     assert "petrophysical" in swof
 
@@ -359,7 +389,7 @@ def test_capillary_pressure():
     pyscal_list = PyscalFactory.create_pyscal_list(
         PyscalFactory.load_relperm_df(dframe)
     )
-    swof = pyscal_list.dump_family_1()
+    swof = pyscal_list.build_eclipse_data(family=1)
     assert "normalized J-function" in swof
     assert "sigma_costau" in swof
     assert "petrophysical" not in swof
@@ -460,7 +490,7 @@ def test_swl_from_height():
     assert np.isclose(pyscal_list[1].swl, 0.157461)
 
 
-def test_twophase():
+def test_twophase_scal_wateroil():
     """Test interpolation for a two-phase setup water-oil"""
     # Triggers bug in pyscal <= 0.5.0
     dframe = pd.DataFrame(
@@ -476,15 +506,36 @@ def test_twophase():
     )
     pyscal_list = pyscal_list.interpolate(-0.5)
 
-    # This works, but provides an error message that Gas.
+    # This works, but provides an error message for Gas.
     # The correct usage would be to call .SWOF(), but the pyscal
-    # client calls dump_family_1 on two-phase problems.
-    swof = pyscal_list.dump_family_1()
+    # client calls 1 on two-phase problems.
+    swof = pyscal_list.build_eclipse_data(family=1)
     assert "thetag" in swof
     assert "SWOF" in swof
     assert "SGOF" not in swof
 
 
+def test_twophase_scal_gasoil():
+    """Test interpolation for a two-phase setup gas-oil"""
+    dframe = pd.DataFrame(
+        columns=["SATNUM", "CASE", "NG", "NOG", "TAG"],
+        data=[
+            [1, "pess", 1, 1, "thetag"],
+            [1, "base", 2, 2, "thetag"],
+            [1, "opt", 3, 3, "thetag"],
+        ],
+    )
+    pyscal_list = PyscalFactory.create_scal_recommendation_list(
+        PyscalFactory.load_relperm_df(dframe)
+    )
+    pyscal_list = pyscal_list.interpolate(-0.5)
+
+    sgof = pyscal_list.build_eclipse_data(family=1)
+    assert "thetag" in sgof
+    assert "SGOF" in sgof
+    assert "SWOF" not in sgof
+
+
 def test_gaswater():
     """Test list of gas-water objects"""
     dframe = pd.DataFrame(
@@ -495,7 +546,7 @@ def test_gaswater():
         PyscalFactory.load_relperm_df(dframe), h=0.1
     )
     assert pyscal_list.pyscaltype == GasWater
-    dump = pyscal_list.dump_family_2()
+    dump = pyscal_list.build_eclipse_data(family=2)
     assert "SATNUM 2" in dump
     assert "SATNUM 1" in dump
     assert "SATNUM 3" not in dump
@@ -504,9 +555,20 @@ def test_gaswater():
     assert "othertag" in dump
     assert "thetag" in dump
 
-    with pytest.raises(ValueError):
-        # Does not make sense for GasWater:
-        pyscal_list.dump_family_1()
+    with pytest.raises(ValueError, match="Family 1 output not possible for GasWater"):
+        pyscal_list.build_eclipse_data(family=1)
+
+    sgfn = pyscal_list.SGFN()
+    assert "SGFN" in sgfn
+    assert "krw = krg" in sgfn
+    swfn = pyscal_list.SWFN()
+    assert "SWFN" in swfn
+    assert "krw = krg" in swfn
+
+    with pytest.raises(
+        AttributeError, match="'GasWater' object has no attribute 'SWOF'"
+    ):
+        pyscal_list.SWOF()
 
 
 def test_gaswater_scal():
@@ -524,6 +586,10 @@ def test_gaswater_scal():
     )
     assert pyscal_list.pyscaltype == SCALrecommendation
 
+    dump = pyscal_list.interpolate(-1).build_eclipse_data(family=2)
+    assert "SWFN" in dump
+    assert "SGFN" in dump
+
 
 def test_explicit_df():
     """Test some dataframes, check the error messages given"""
@@ -565,15 +631,15 @@ def test_explicit_df():
     dframe = pd.DataFrame(columns=["SATNUM", "Nw", "Now"], data=[[1, 2, 2]])
     relperm_data = PyscalFactory.load_relperm_df(dframe)
     p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
-    p_list.dump_family_1()
+    p_list.build_eclipse_data(family=1)
     with pytest.raises(ValueError):
-        p_list.dump_family_2()
+        p_list.build_eclipse_data(family=2)
 
     # Case insensitive for parameters
     dframe = pd.DataFrame(columns=["SATNUM", "nw", "now"], data=[[1, 2, 2]])
     relperm_data = PyscalFactory.load_relperm_df(dframe)
     p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
-    p_list.dump_family_1()
+    p_list.build_eclipse_data(family=1)
 
     # Minimal wateroilgas
     dframe = pd.DataFrame(
@@ -581,7 +647,7 @@ def test_explicit_df():
     )
     relperm_data = PyscalFactory.load_relperm_df(dframe)
     p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
-    relperm_str = p_list.dump_family_1()
+    relperm_str = p_list.build_eclipse_data(family=1)
     assert "SWOF" in relperm_str
     assert "SGOF" in relperm_str
     assert "SLGOF" not in relperm_str
@@ -606,7 +672,7 @@ def test_explicit_df():
     )
     relperm_data = PyscalFactory.load_relperm_df(dframe)
     p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
-    relperm_str = p_list.dump_family_1()
+    relperm_str = p_list.build_eclipse_data(family=1)
     assert "SWOF" in relperm_str
     assert "Simplified" in relperm_str  # Bad practice, testing for stuff in comments
     assert "a=1.5" in relperm_str
@@ -620,7 +686,7 @@ def test_comments_df():
     )
     relperm_data = PyscalFactory.load_relperm_df(dframe)
     p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
-    relperm_str = p_list.dump_family_1()
+    relperm_str = p_list.build_eclipse_data(family=1)
     assert "thisisacomment" in relperm_str
 
     # tag vs comment in dataframe should not matter.
@@ -630,7 +696,7 @@ def test_comments_df():
     )
     relperm_data = PyscalFactory.load_relperm_df(dframe)
     p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
-    relperm_str = p_list.dump_family_1()
+    relperm_str = p_list.build_eclipse_data(family=1)
     assert relperm_str.count("thisisacomment") == 2
 
     # Check case insensitiveness:
@@ -640,7 +706,7 @@ def test_comments_df():
     )
     relperm_data = PyscalFactory.load_relperm_df(dframe)
     p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
-    assert p_list.dump_family_1().count("thisisacomment") == 2
+    assert p_list.build_eclipse_data(family=1).count("thisisacomment") == 2
 
     # UTF-8 stuff:
     dframe = pd.DataFrame(
@@ -649,10 +715,10 @@ def test_comments_df():
     )
     relperm_data = PyscalFactory.load_relperm_df(dframe)
     p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
-    assert p_list.dump_family_1().count("æøå") == 2
+    assert p_list.build_eclipse_data(family=1).count("æøå") == 2
 
 
-def test_error_messages_pr_satnum(caplog):
+def test_error_messages_pr_satnum():
     """When errors are somewhere in a big dataframe, we should
     provide hints to the user for where to look"""
 
@@ -725,7 +791,7 @@ def test_error_messages_pr_satnum(caplog):
 
 
 def test_fast():
-    """Test fast mode for SCALrecommendation"""
+    """Test fast mode for SCALrecmmendation"""
     testdir = Path(__file__).absolute().parent
 
     scalrec_data = PyscalFactory.load_relperm_df(
