@@ -1,15 +1,12 @@
 """Test module for SLGOF export from GasOil"""
 
-from hypothesis import given, settings
 import hypothesis.strategies as st
-
 import numpy as np
-
 import pytest
+from hypothesis import given
 
-from pyscal import WaterOilGas, GasOil
-from pyscal.constants import SWINTEGERS, EPSILON
-
+from pyscal import GasOil, WaterOilGas
+from pyscal.constants import EPSILON, SWINTEGERS
 from pyscal.utils.testing import sat_table_str_ok
 
 
@@ -27,7 +24,6 @@ def check_table(dframe):
         assert dframe["PC"].is_monotonic_decreasing
 
 
-@settings(deadline=1000)
 @given(
     st.floats(min_value=0.0, max_value=0.3),
     st.floats(min_value=0.0, max_value=0.3),
@@ -57,28 +53,67 @@ def test_slgof(swl, sorg, sgcr):
     assert np.isclose(slgof["KRG"].values[-1], 0)
     assert np.isclose(slgof["KROG"].values[0], 0)
 
+    # If we ruin the object, SLGOF() will return an empty string:
+    wog.gasoil.table.drop("KRG", axis="columns", inplace=True)
+    assert wog.gasoil.SLGOF() == ""
+    assert wog.SLGOF() == ""
+
 
 @pytest.mark.parametrize(
     "swl, sorg, sgcr",
     [
-        # Parameter combinations exposed by pytest.hypothesis:
-        (0.029950000000000105, 0.0, 0.01994999999999992),
-        (0.285053445121882, 0.24900257734119435, 0.1660017182274629),
+        (0.0, 0.0, 0.1),
+        (1e-18, 0.0, 0.1),
+        (1e-17, 0.0, 0.1),
+        (1e-16, 0.0, 0.1),
+        (1e-15, 0.0, 0.1),
+        (1e-14, 0.0, 0.1),
+        (1e-13, 0.0, 0.1),
+        (1e-12, 0.0, 0.1),
+        (1e-11, 0.0, 0.1),
+        (1e-10, 0.0, 0.1),
+        #
+        (0.1, 0.0, 0.1),
+        (0.1, 1e-18, 0.1),
+        (0.1, 1e-17, 0.1),
+        (0.1, 1e-16, 0.1),
+        (0.1, 1e-15, 0.1),
+        (0.1, 1e-14, 0.1),
+        (0.1, 1e-13, 0.1),
+        (0.1, 1e-12, 0.1),
+        (0.1, 1e-11, 0.1),
+        (0.1, 1e-10, 0.1),
+        #
+        (0.1, 0.0, 0.0),
+        (0.1, 0.0, 1e-18),
+        (0.1, 0.0, 1e-17),
+        (0.1, 0.0, 1e-16),
+        (0.1, 0.0, 1e-15),
+        (0.1, 0.0, 1e-14),
+        (0.1, 0.0, 1e-13),
+        (0.1, 0.0, 1e-12),
+        (0.1, 0.0, 1e-11),
+        (0.1, 0.0, 1e-10),
+        #
+        (0.1 - 0.0, 0.0, 0.1),
+        (0.1 - 1e-18, 0.0, 0.1),
+        (0.1 - 1e-17, 0.0, 0.1),
+        (0.1 - 1e-16, 0.0, 0.1),
+        (0.1 - 1e-15, 0.0, 0.1),
+        (0.1 - 1e-14, 0.0, 0.1),
+        (0.1 - 1e-13, 0.0, 0.1),
+        (0.1 - 1e-12, 0.0, 0.1),
+        (0.1 - 1e-11, 0.0, 0.1),
+        (0.1 - 1e-10, 0.0, 0.1),
     ],
 )
 def test_numerical_problems(swl, sorg, sgcr):
-    """Test fine-tuned numerics for slgof, this function should
-    trigger the code path in slgof_df() where slgof_sl_mismatch is small.
-
-    Note: The code path taken may depend on hardware/OS etc.
-    """
+    """Test fine-tuned numerics for slgof"""
 
     # Because we cut away some saturation points due to SWINTEGERS, we easily
     # end in a situation where the wrong saturation point of to "equal" ones
     # is removed (because in SLGOF, sg is flipped to sl)
 
-    # Unrounded, this represents a numerical difficulty, when h is low enough,
-    # but there is special code in slgof_df() to workaround this.
     gasoil = GasOil(swl=swl, sorg=sorg, sgcr=sgcr, h=0.001)
     gasoil.add_corey_gas()
     gasoil.add_corey_oil()
@@ -89,12 +124,11 @@ def test_numerical_problems(swl, sorg, sgcr):
     check_table(slgof)
 
 
-@settings(deadline=2000)  # This is slow for small h
 @given(
     st.floats(min_value=0.0, max_value=0.3),
     st.floats(min_value=0.0, max_value=0.3),
     st.floats(min_value=0.0, max_value=0.3),
-    st.floats(min_value=1.0 / float(SWINTEGERS), max_value=0.5),
+    st.floats(min_value=1.0 / float(1000 * SWINTEGERS), max_value=0.5),
 )
 def test_slgof_hypo(swl, sorg, sgcr, h):
     """Shotgun-testing of slgof"""
@@ -112,3 +146,19 @@ def test_slgof_hypo(swl, sorg, sgcr, h):
     assert isinstance(slgof_str, str)
     assert slgof_str
     sat_table_str_ok(slgof_str)
+
+
+@given(
+    st.floats(min_value=0.0, max_value=0.3),
+    st.floats(min_value=0.0, max_value=0.3),
+    st.floats(min_value=1.0 / float(1000 * SWINTEGERS), max_value=0.5),
+)
+def test_slgof_sl_mismatch(swl, sorg, h):
+    """Test numerical robustness on slgof table creation."""
+    gasoil = GasOil(h=h, swl=swl, sorg=sorg)
+    gasoil.add_corey_gas()
+    gasoil.add_corey_oil()
+
+    # It is a strict requirement that the first sl value should be swl + sorg,
+    # but GasOil might have truncated the values.
+    assert np.isclose(gasoil.slgof_df()["SL"].values[0] - (gasoil.swl + gasoil.sorg), 0)
